'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var styled = require('styled-components');
var styled__default = _interopDefault(styled);

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
/* eslint-disable no-unused-vars */
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;

function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}

	return Object(val);
}

function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}

		// Detect buggy property enumeration order in older V8 versions.

		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}

		return true;
	} catch (err) {
		// We don't expect any of the above to throw, but better to be safe.
		return false;
	}
}

var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;

	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);

		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}

		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}

	return to;
};

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

var ReactPropTypesSecret_1 = ReactPropTypesSecret;

var printWarning = function() {};

if (process.env.NODE_ENV !== 'production') {
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};

  printWarning = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

/**
 * Assert that the values match with the type specs.
 * Error messages are memorized and will only be shown once.
 *
 * @param {object} typeSpecs Map of name to a ReactPropType
 * @param {object} values Runtime values that need to be type-checked
 * @param {string} location e.g. "prop", "context", "child context"
 * @param {string} componentName Name of the component for error messages.
 * @param {?Function} getStack Returns the component stack.
 * @private
 */
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  if (process.env.NODE_ENV !== 'production') {
    for (var typeSpecName in typeSpecs) {
      if (typeSpecs.hasOwnProperty(typeSpecName)) {
        var error;
        // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.
        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error(
              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'
            );
            err.name = 'Invariant Violation';
            throw err;
          }
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        if (error && !(error instanceof Error)) {
          printWarning(
            (componentName || 'React class') + ': type specification of ' +
            location + ' `' + typeSpecName + '` is invalid; the type checker ' +
            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
            'You may have forgotten to pass an argument to the type checker ' +
            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
            'shape all require an argument).'
          );

        }
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error.message] = true;

          var stack = getStack ? getStack() : '';

          printWarning(
            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
          );
        }
      }
    }
  }
}

var checkPropTypes_1 = checkPropTypes;

var printWarning$1 = function() {};

if (process.env.NODE_ENV !== 'production') {
  printWarning$1 = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

function emptyFunctionThatReturnsNull() {
  return null;
}

var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  /* global Symbol */
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

  /**
   * Returns the iterator method function contained on the iterable object.
   *
   * Be sure to invoke the function with the iterable as context:
   *
   *     var iteratorFn = getIteratorFn(myIterable);
   *     if (iteratorFn) {
   *       var iterator = iteratorFn.call(myIterable);
   *       ...
   *     }
   *
   * @param {?object} maybeIterable
   * @return {?function}
   */
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }

  /**
   * Collection of methods that allow declaration and validation of props that are
   * supplied to React components. Example usage:
   *
   *   var Props = require('ReactPropTypes');
   *   var MyArticle = React.createClass({
   *     propTypes: {
   *       // An optional string prop named "description".
   *       description: Props.string,
   *
   *       // A required enum prop named "category".
   *       category: Props.oneOf(['News','Photos']).isRequired,
   *
   *       // A prop named "dialog" that requires an instance of Dialog.
   *       dialog: Props.instanceOf(Dialog).isRequired
   *     },
   *     render: function() { ... }
   *   });
   *
   * A more formal specification of how these methods are used:
   *
   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
   *   decl := ReactPropTypes.{type}(.isRequired)?
   *
   * Each and every declaration produces a function with the same signature. This
   * allows the creation of custom validation functions. For example:
   *
   *  var MyLink = React.createClass({
   *    propTypes: {
   *      // An optional string or URI prop named "href".
   *      href: function(props, propName, componentName) {
   *        var propValue = props[propName];
   *        if (propValue != null && typeof propValue !== 'string' &&
   *            !(propValue instanceof URI)) {
   *          return new Error(
   *            'Expected a string or an URI for ' + propName + ' in ' +
   *            componentName
   *          );
   *        }
   *      }
   *    },
   *    render: function() {...}
   *  });
   *
   * @internal
   */

  var ANONYMOUS = '<<anonymous>>';

  // Important!
  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),

    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker,
    exact: createStrictShapeTypeChecker,
  };

  /**
   * inlined Object.is polyfill to avoid requiring consumers ship their own
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
   */
  /*eslint-disable no-self-compare*/
  function is(x, y) {
    // SameValue algorithm
    if (x === y) {
      // Steps 1-5, 7-10
      // Steps 6.b-6.e: +0 != -0
      return x !== 0 || 1 / x === 1 / y;
    } else {
      // Step 6.a: NaN == NaN
      return x !== x && y !== y;
    }
  }
  /*eslint-enable no-self-compare*/

  /**
   * We use an Error-like object for backward compatibility as people may call
   * PropTypes directly and inspect their output. However, we don't use real
   * Errors anymore. We don't inspect their stack anyway, and creating them
   * is prohibitively expensive if they are created too often, such as what
   * happens in oneOfType() for any type before the one that matched.
   */
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  // Make `instanceof Error` still work for returned errors.
  PropTypeError.prototype = Error.prototype;

  function createChainableTypeChecker(validate) {
    if (process.env.NODE_ENV !== 'production') {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;

      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          // New behavior only for users of `prop-types` package
          var err = new Error(
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
          err.name = 'Invariant Violation';
          throw err;
        } else if (process.env.NODE_ENV !== 'production' && typeof console !== 'undefined') {
          // Old behavior for people using React.PropTypes
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            // Avoid spamming the console because they are often not actionable except for lib authors
            manualPropTypeWarningCount < 3
          ) {
            printWarning$1(
              'You are manually calling a React.PropTypes validation ' +
              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }

    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);

    return chainedCheckType;
  }

  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        // `propValue` being instance of, say, date/regexp, pass the 'object'
        // check, but we can offer a more precise error message here rather than
        // 'of type `object`'.
        var preciseType = getPreciseType(propValue);

        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunctionThatReturnsNull);
  }

  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOf, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }

      var valuesString = JSON.stringify(expectedValues);
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + propValue + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (propValue.hasOwnProperty(key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOfType, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        printWarning$1(
          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
        );
        return emptyFunctionThatReturnsNull;
      }
    }

    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }

      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createStrictShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      // We need to check all keys in case some are required but missing from
      // props.
      var allKeys = objectAssign({}, props[propName], shapeTypes);
      for (var key in allKeys) {
        var checker = shapeTypes[key];
        if (!checker) {
          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
            '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
            '\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')
          );
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }

    return createChainableTypeChecker(validate);
  }

  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }

        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            // Iterator will provide entry [k,v] tuples rather than values.
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }

        return true;
      default:
        return false;
    }
  }

  function isSymbol(propType, propValue) {
    // Native Symbol.
    if (propType === 'symbol') {
      return true;
    }

    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }

    // Fallback for non-spec compliant Symbols which are polyfilled.
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }

    return false;
  }

  // Equivalent of `typeof` but with special handling for array and regexp.
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      // Old webkits (at least until Android 4.0) return 'function' rather than
      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
      // passes PropTypes.object.
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }

  // This handles more types than `getPropType`. Only used for error messages.
  // See `createPrimitiveTypeChecker`.
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }

  // Returns a string that is postfixed to a warning about an invalid type.
  // For example, "undefined" or "of type array"
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }

  // Returns class name of the object, if any.
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }

  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

function emptyFunction() {}

var factoryWithThrowingShims = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret_1) {
      // It is still safe when called from React.
      return;
    }
    var err = new Error(
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
    err.name = 'Invariant Violation';
    throw err;
  }  shim.isRequired = shim;
  function getShim() {
    return shim;
  }  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim,
    exact: getShim
  };

  ReactPropTypes.checkPropTypes = emptyFunction;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var propTypes = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

if (process.env.NODE_ENV !== 'production') {
  var REACT_ELEMENT_TYPE = (typeof Symbol === 'function' &&
    Symbol.for &&
    Symbol.for('react.element')) ||
    0xeac7;

  var isValidElement = function(object) {
    return typeof object === 'object' &&
      object !== null &&
      object.$$typeof === REACT_ELEMENT_TYPE;
  };

  // By explicitly using `prop-types` you are opting into new development behavior.
  // http://fb.me/prop-types-in-prod
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(isValidElement, throwOnDirectAccess);
} else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = factoryWithThrowingShims();
}
});

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var slicedToArray = function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
}();

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

var _templateObject = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2 = taggedTemplateLiteral(['\n    font-size: ', ';\n    background: ', ';\n    border-radius: ', ';\n    box-shadow: ', ';\n    display: flex;\n    flex-direction: column;\n    position: relative;\n    height: 100%;\n    header {\n      color: ', ';\n      padding: ', ';\n      border-bottom: 1px solid ', ';\n      border-top-left-radius: ', ';\n      border-top-right-radius: ', ';\n      font-weight: ', ';\n    }\n\n    .scrollable {\n      overflow: auto;\n      flex: 1;\n    }\n\n    .messages {\n      padding: ', ';\n      overflow-y: auto;\n      overflow-x: hidden;\n      display: flex;\n      flex-shrink: 0;\n      flex-direction: column;\n    }\n\n    .no-messages {\n      font-size: 0.875rem;\n      text-align: center;\n    }\n\n    ', '\n    ', '\n  '], ['\n    font-size: ', ';\n    background: ', ';\n    border-radius: ', ';\n    box-shadow: ', ';\n    display: flex;\n    flex-direction: column;\n    position: relative;\n    height: 100%;\n    header {\n      color: ', ';\n      padding: ', ';\n      border-bottom: 1px solid ', ';\n      border-top-left-radius: ', ';\n      border-top-right-radius: ', ';\n      font-weight: ', ';\n    }\n\n    .scrollable {\n      overflow: auto;\n      flex: 1;\n    }\n\n    .messages {\n      padding: ', ';\n      overflow-y: auto;\n      overflow-x: hidden;\n      display: flex;\n      flex-shrink: 0;\n      flex-direction: column;\n    }\n\n    .no-messages {\n      font-size: 0.875rem;\n      text-align: center;\n    }\n\n    ', '\n    ', '\n  ']),
    _templateObject3 = taggedTemplateLiteral(['\n        header {\n          background-color: ', ';\n          color: ', ';\n        }\n        ', ' button.btn {\n          background-color: ', ';\n          ', '\n        }\n      '], ['\n        header {\n          background-color: ', ';\n          color: ', ';\n        }\n        ', ' button.btn {\n          background-color: ', ';\n          ', '\n        }\n      ']),
    _templateObject4 = taggedTemplateLiteral(['\n              border: 1px solid ', ';\n              color: ', ';\n            '], ['\n              border: 1px solid ', ';\n              color: ', ';\n            ']),
    _templateObject5 = taggedTemplateLiteral(['\n    display: flex;\n    flex-direction: column;\n    padding: ', ';\n    border-top: 1px solid ', ';\n    .message-row {\n      flex-direction: row;\n      display: flex;\n    }\n    input {\n      flex: 1;\n      padding: 1.25rem 1.5rem;\n      border-radius: 2rem;\n      border: 1px solid ', ';\n      background: ', ';\n      color: ', ';\n      outline: none;\n      box-sizing: border-box;\n      ', ' \n      &::placeholder {\n        color: ', ';\n      }\n    }\n\n    button.btn {\n      border-radius: 3rem;\n      border-top-', '-radius: 0;\n      border-bottom-', '-radius: 0;\n      padding: 0 1.5rem;\n\n      ', '\n    }\n\n    ', ' \n\n    .dropped-files {\n      display: flex;\n      flex-direction: row;\n      margin-bottom: 0.5rem;\n      flex-wrap: wrap;\n\n      div {\n        background-size: cover;\n        width: 3rem;\n        height: 3rem;\n        border-radius: 0.5rem;\n        margin-', ': 0.5rem;\n        margin-bottom: 0.5rem;\n        border: 1px solid ', ';\n        text-align: center;\n        line-height: 3rem;\n        font-size: 2rem;\n        color: ', ';\n        position: relative;\n\n        .remove {\n          position: absolute;\n          right: -0.5rem;\n          top: -0.875rem;\n          font-size: 0.875rem;\n          line-height: 1;\n          cursor: pointer;\n        }\n      }\n    }\n  '], ['\n    display: flex;\n    flex-direction: column;\n    padding: ', ';\n    border-top: 1px solid ', ';\n    .message-row {\n      flex-direction: row;\n      display: flex;\n    }\n    input {\n      flex: 1;\n      padding: 1.25rem 1.5rem;\n      border-radius: 2rem;\n      border: 1px solid ', ';\n      background: ', ';\n      color: ', ';\n      outline: none;\n      box-sizing: border-box;\n      ', ' \n      &::placeholder {\n        color: ', ';\n      }\n    }\n\n    button.btn {\n      border-radius: 3rem;\n      border-top-', '-radius: 0;\n      border-bottom-', '-radius: 0;\n      padding: 0 1.5rem;\n\n      ', '\n    }\n\n    ', ' \n\n    .dropped-files {\n      display: flex;\n      flex-direction: row;\n      margin-bottom: 0.5rem;\n      flex-wrap: wrap;\n\n      div {\n        background-size: cover;\n        width: 3rem;\n        height: 3rem;\n        border-radius: 0.5rem;\n        margin-', ': 0.5rem;\n        margin-bottom: 0.5rem;\n        border: 1px solid ', ';\n        text-align: center;\n        line-height: 3rem;\n        font-size: 2rem;\n        color: ', ';\n        position: relative;\n\n        .remove {\n          position: absolute;\n          right: -0.5rem;\n          top: -0.875rem;\n          font-size: 0.875rem;\n          line-height: 1;\n          cursor: pointer;\n        }\n      }\n    }\n  ']),
    _templateObject6 = taggedTemplateLiteral(['\n        border-top-', '-radius: 0;\n        border-bottom-', '-radius: 0;\n      '], ['\n        border-top-', '-radius: 0;\n        border-bottom-', '-radius: 0;\n      ']),
    _templateObject7 = taggedTemplateLiteral(['\n          font-size: 3rem;\n          line-height: 1;\n          padding: 0 1.25rem 0 0.875rem;\n          text-align: center;\n        '], ['\n          font-size: 3rem;\n          line-height: 1;\n          padding: 0 1.25rem 0 0.875rem;\n          text-align: center;\n        ']),
    _templateObject8 = taggedTemplateLiteral(['\n        input {\n          border: 1px dashed ', ';\n          box-shadow: 0 0 0 4px ', ';\n          &::placeholder {\n            color: ', ';\n          }\n        }\n      '], ['\n        input {\n          border: 1px dashed ', ';\n          box-shadow: 0 0 0 4px ', ';\n          &::placeholder {\n            color: ', ';\n          }\n        }\n      ']),
    _templateObject9 = taggedTemplateLiteral(['\n    margin-bottom: 1.5rem;\n    display: flex;\n    flex-direction: row;\n    .message {\n      flex: 1;\n    }\n    .avatar {\n      border-radius: 50%;\n      flex-shrink: 0;\n      background: ', ';\n      background-position: center;\n      background-size: 3.4rem 2.6rem;\n      background-repeat: no-repeat;\n      width: 2.5rem;\n      height: 2.5rem;\n      text-align: center;\n      line-height: 2.5rem;\n      font-size: 0.875rem;\n      color: white;\n    }\n    ', '\n  '], ['\n    margin-bottom: 1.5rem;\n    display: flex;\n    flex-direction: row;\n    .message {\n      flex: 1;\n    }\n    .avatar {\n      border-radius: 50%;\n      flex-shrink: 0;\n      background: ', ';\n      background-position: center;\n      background-size: 3.4rem 2.6rem;\n      background-repeat: no-repeat;\n      width: 2.5rem;\n      height: 2.5rem;\n      text-align: center;\n      line-height: 2.5rem;\n      font-size: 0.875rem;\n      color: white;\n    }\n    ', '\n  ']),
    _templateObject10 = taggedTemplateLiteral(['\n      flex-direction: row-reverse;\n      .message {\n        margin-left: 0;\n        margin-', ': 0.5rem;\n        margin-', ': 3rem;\n      }\n      ', ' {\n        align-items: flex-end;\n        .sender {\n          text-align: ', ';\n        }\n        .text {\n          border-top-', '-radius: 0;\n          background: ', ';\n          color: ', ';\n        }\n      }\n      ', ' {\n        align-items: flex-end;\n      }\n    '], ['\n      flex-direction: row-reverse;\n      .message {\n        margin-left: 0;\n        margin-', ': 0.5rem;\n        margin-', ': 3rem;\n      }\n      ', ' {\n        align-items: flex-end;\n        .sender {\n          text-align: ', ';\n        }\n        .text {\n          border-top-', '-radius: 0;\n          background: ', ';\n          color: ', ';\n        }\n      }\n      ', ' {\n        align-items: flex-end;\n      }\n    ']),
    _templateObject11 = taggedTemplateLiteral(['\n      .message {\n        margin-', ': 0.5rem;\n        margin-', ': 3rem;\n      }\n      ', ' {\n        align-items: flex-start;\n        .text {\n          border-top-', '-radius: 0;\n          background: ', ';\n          color: ', ';\n        }\n      }\n      ', ' {\n        align-items: flex-start;\n      }\n    '], ['\n      .message {\n        margin-', ': 0.5rem;\n        margin-', ': 3rem;\n      }\n      ', ' {\n        align-items: flex-start;\n        .text {\n          border-top-', '-radius: 0;\n          background: ', ';\n          color: ', ';\n        }\n      }\n      ', ' {\n        align-items: flex-start;\n      }\n    ']),
    _templateObject12 = taggedTemplateLiteral(['\n    display: flex;\n    flex-direction: column;\n    .sender {\n      font-size: 0.875rem;\n      color: ', ';\n      margin-bottom: 0.5rem;\n    }\n    p {\n      word-wrap: break-word;\n      word-break: break-all;\n      max-width: 100%;\n      margin: 0;\n    }\n    .text {\n      padding: 1rem;\n      border-radius: 0.5rem;\n    }\n  '], ['\n    display: flex;\n    flex-direction: column;\n    .sender {\n      font-size: 0.875rem;\n      color: ', ';\n      margin-bottom: 0.5rem;\n    }\n    p {\n      word-wrap: break-word;\n      word-break: break-all;\n      max-width: 100%;\n      margin: 0;\n    }\n    .text {\n      padding: 1rem;\n      border-radius: 0.5rem;\n    }\n  ']),
    _templateObject13 = taggedTemplateLiteral(['\n    display: flex;\n    flex-direction: column;\n    a {\n      color: ', ';\n      background: ', ';\n      font-size: 4rem;\n      text-align: center;\n      border: 1px solid ', ';\n      width: 10rem;\n      height: 10rem;\n      overflow: hidden;\n      display: flex;\n      justify-content: center;\n      align-items: center;\n      flex-shrink: 0;\n      border-radius: 0.5rem;\n      &:hover,\n      &:focus {\n        text-decoration: none;\n        color: ', ';\n      }\n      div {\n        background-size: cover;\n        width: 100%;\n        height: 100%;\n      }\n    }\n    ', ' {\n      display: block;\n      margin-bottom: 0.5rem;\n    }\n    .message-content-group {\n      display: flex;\n      flex-direction: row;\n      justify-content: flex-end;\n      flex-wrap: wrap;\n      a {\n        margin-', ': 1rem;\n        margin-bottom: 1rem;\n        width: 5rem;\n        height: 5rem;\n      }\n    }\n  '], ['\n    display: flex;\n    flex-direction: column;\n    a {\n      color: ', ';\n      background: ', ';\n      font-size: 4rem;\n      text-align: center;\n      border: 1px solid ', ';\n      width: 10rem;\n      height: 10rem;\n      overflow: hidden;\n      display: flex;\n      justify-content: center;\n      align-items: center;\n      flex-shrink: 0;\n      border-radius: 0.5rem;\n      &:hover,\n      &:focus {\n        text-decoration: none;\n        color: ', ';\n      }\n      div {\n        background-size: cover;\n        width: 100%;\n        height: 100%;\n      }\n    }\n    ', ' {\n      display: block;\n      margin-bottom: 0.5rem;\n    }\n    .message-content-group {\n      display: flex;\n      flex-direction: row;\n      justify-content: flex-end;\n      flex-wrap: wrap;\n      a {\n        margin-', ': 1rem;\n        margin-bottom: 1rem;\n        width: 5rem;\n        height: 5rem;\n      }\n    }\n  ']),
    _templateObject14 = taggedTemplateLiteral(['\n    p.quote {\n      font-style: italic;\n      font-size: 0.875rem;\n      background: ', ';\n      color: ', ';\n      padding: 1rem;\n      border-radius: 0.5rem;\n      margin-bottom: 0.5rem;\n    }\n    .sender {\n      font-size: 0.875rem;\n      color: ', ';\n      margin-bottom: 0.5rem;\n    }\n  '], ['\n    p.quote {\n      font-style: italic;\n      font-size: 0.875rem;\n      background: ', ';\n      color: ', ';\n      padding: 1rem;\n      border-radius: 0.5rem;\n      margin-bottom: 0.5rem;\n    }\n    .sender {\n      font-size: 0.875rem;\n      color: ', ';\n      margin-bottom: 0.5rem;\n    }\n  ']);

var ChatStyle = styled__default.div(_templateObject, function (_ref) {
  var theme = _ref.theme,
      size = _ref.size,
      status = _ref.status;
  return styled.css(_templateObject2, theme.chatFontSize, theme.chatBg, theme.chatBorderRadius, theme.chatShadow, theme.chatFg, theme.chatPadding, theme.chatSeparator, theme.chatBorderRadius, theme.chatBorderRadius, theme.fontWeightBolder, theme.chatPadding, size && 'height: ' + theme['chatHeight' + size] + ';', status && styled.css(_templateObject3, theme['chat' + status + 'Bg'], theme['chat' + status + 'Fg'], FormStyle, theme['chat' + status + 'Bg'], status === 'Disabled' && styled.css(_templateObject4, theme.chatFormBorder, theme.chatDisabledFg)));
});

var FormStyle = styled__default.div(_templateObject, function (_ref2) {
  var theme = _ref2.theme,
      fileOver = _ref2.fileOver,
      showButton = _ref2.showButton,
      buttonIcon = _ref2.buttonIcon;
  return styled.css(_templateObject5, theme.chatPadding, theme.chatSeparator, theme.chatFormBorder, theme.chatFormBg, theme.chatFormFg, showButton && styled.css(_templateObject6, theme.dir === 'rtl' ? 'left' : 'right', theme.dir === 'rtl' ? 'left' : 'right'), theme.chatFormPlaceholderFg, theme.dir === 'rtl' ? 'right' : 'left', theme.dir === 'rtl' ? 'right' : 'left', buttonIcon && styled.css(_templateObject7), fileOver && styled.css(_templateObject8, theme.chatFormActiveBorder, theme.chatFormBg, theme.chatFormFg), theme.dir === 'rtl' ? 'left' : 'right', theme.chatFormFg, theme.chatFormFg);
});

var MessageStyle = styled__default.div(_templateObject, function (_ref3) {
  var theme = _ref3.theme,
      reply = _ref3.reply;
  return styled.css(_templateObject9, theme.chatMessageAvatarBg, reply ? styled.css(_templateObject10, theme.dir === 'rtl' ? 'left' : 'right', theme.dir === 'rtl' ? 'right' : 'left', MessageTextStyle, theme.dir === 'rtl' ? 'left' : 'right', theme.dir === 'rtl' ? 'left' : 'right', theme.chatMessageReplyBg, theme.chatMessageReplyFg, MessageFileStyle) : styled.css(_templateObject11, theme.dir === 'rtl' ? 'right' : 'left', theme.dir === 'rtl' ? 'left' : 'right', MessageTextStyle, theme.dir === 'rtl' ? 'right' : 'left', theme.chatMessageBg, theme.chatMessageFg, MessageFileStyle));
});

var MessageTextStyle = styled__default.div(_templateObject, function (_ref4) {
  var theme = _ref4.theme;
  return styled.css(_templateObject12, theme.chatMessageSenderFg);
});

var MessageFileStyle = styled__default.div(_templateObject, function (_ref5) {
  var theme = _ref5.theme;
  return styled.css(_templateObject13, theme.chatMessageFileFg, theme.chatMessageFileBg, theme.chatMessageFileFg, theme.chatMessageFileFg, MessageTextStyle, theme.dir === 'rtl' ? 'left' : 'right');
});

var MessageQuoteStyle = styled__default.div(_templateObject, function (_ref6) {
  var theme = _ref6.theme;
  return styled.css(_templateObject14, theme.chatMessageQuoteBg, theme.chatMessageQuoteFg, theme.chatMessageSenderFg);
});

function MessageText(props) {
  return React__default.createElement(
    MessageTextStyle,
    null,
    (props.sender || props.date) && React__default.createElement(
      'p',
      { className: 'sender' },
      props.sender,
      ' ',
      React__default.createElement(
        'time',
        null,
        props.date
      )
    ),
    props.message && React__default.createElement(
      'p',
      { className: 'text' },
      ' ',
      props.message
    )
  );
}

function MessageFile(props) {
  var isImages = function isImages(file) {
    return ['image/png', 'image/jpeg', 'image/gif'].includes(file.type);
  };
  var readyFiles = function readyFiles() {
    return props.files.map(function (file) {
      var isImage = isImages(file);
      return _extends({}, file, {
        urlStyle: isImage && 'url(' + file.url + ')',
        isImage: isImage
      });
    });
  };

  return React__default.createElement(
    MessageFileStyle,
    null,
    React__default.createElement(MessageText, {
      sender: props.sender,
      message: props.message,
      date: props.date
    }),
    readyFiles().length > 1 ? React__default.createElement(
      'div',
      { className: 'message-content-group' },
      readyFiles().map(function (file, index) {
        return React__default.createElement(
          'a',
          {
            key: index,
            href: file.url,
            target: '_blank',
            rel: 'noopener noreferrer'
          },
          !file.urlStyle && React__default.createElement('span', { className: file.icon }),
          file.isImage && React__default.createElement('div', { style: { backgroundImage: file.urlStyle } })
        );
      })
    ) : readyFiles().length === 1 && React__default.createElement(
      'a',
      {
        href: readyFiles()[0].url,
        target: '_blank',
        rel: 'noopener noreferrer'
      },
      !readyFiles()[0].urlStyle && React__default.createElement('span', { className: readyFiles()[0].icon }),
      readyFiles()[0].isImage && React__default.createElement('div', { style: { backgroundImage: readyFiles()[0].urlStyle } })
    )
  );
}

function MessageMap(props) {
  var file = {
    url: 'https://maps.googleapis.com/maps/api/staticmap?center=' + props.latitude + ',' + props.longitude + '&zoom=12&size=400x400&key=' + props.mapKey,
    type: 'image/png',
    icon: props.icon
  };
  return React__default.createElement(MessageFile, {
    sender: props.sender,
    message: props.message,
    date: props.date,
    files: [file]
  });
}

function MessageQuote(props) {
  return React__default.createElement(
    MessageQuoteStyle,
    null,
    (props.sender || props.date) && React__default.createElement(
      'p',
      { className: 'sender' },
      props.sender,
      ' ',
      React__default.createElement(
        'time',
        null,
        props.date
      )
    ),
    React__default.createElement(
      'p',
      { className: 'quote' },
      props.quote
    ),
    React__default.createElement(MessageText, { message: props.message })
  );
}

function Messages(props) {
  var scrollRef = React.useRef();
  React.useEffect(function () {
    scrollRef.current.scrollTo(0, scrollRef.current.scrollHeight);
  }, [props.messages]);
  var getMessageComponent = function getMessageComponent(msg) {
    switch (msg.type) {
      case 'file':
        return React__default.createElement(MessageFile, {
          sender: msg.sender,
          message: msg.message,
          date: msg.date,
          files: msg.files
        });
      case 'map':
        return React__default.createElement(MessageMap, {
          sender: msg.sender,
          message: msg.message,
          date: msg.date,
          latitude: msg.latitude,
          longitude: msg.longitude,
          mapKey: props.mapKey
        });
      case 'quote':
        return React__default.createElement(MessageQuote, {
          sender: msg.sender,
          message: msg.message,
          date: msg.date,
          quote: msg.quote
        });

      default:
        return React__default.createElement(MessageText, {
          sender: msg.sender,
          message: msg.message,
          date: msg.date
        });
    }
  };
  var getInitials = function getInitials(name) {
    if (name) {
      var names = name.split(' ');

      return names.map(function (n) {
        return n.charAt(0);
      }).splice(0, 2).join('').toUpperCase();
    }

    return '';
  };
  return React__default.createElement(
    'div',
    { className: 'scrollable', ref: scrollRef },
    React__default.createElement(
      'div',
      { className: 'messages' },
      props.messages.map(function (msg, index) {
        return React__default.createElement(
          MessageStyle,
          { reply: msg.reply, key: index },
          !msg.reply && React__default.createElement(
            'div',
            {
              className: 'avatar',
              style: { backgroundImage: 'url(' + msg.avatar + ')' }
            },
            !msg.avatar && getInitials(msg.sender)
          ),
          React__default.createElement(
            'div',
            { className: 'message' },
            getMessageComponent(msg)
          )
        );
      }),
      !props.messages.length && React__default.createElement(
        'p',
        { className: 'no-messages' },
        props.noMessages ? props.noMessages : 'No messages yet.'
      )
    )
  );
}
Messages.propTypes = {
  mapKey: propTypes.string,
  messages: propTypes.arrayOf(propTypes.shape({
    sender: propTypes.string,
    message: propTypes.string,
    date: propTypes.string,
    files: propTypes.arrayOf(propTypes.shape({
      url: propTypes.string,
      icon: propTypes.string,
      type: propTypes.string
    })),
    quote: propTypes.string,
    latitude: propTypes.number,
    longitude: propTypes.number,
    avatar: propTypes.string,
    reply: propTypes.bool,
    type: propTypes.oneOf(['text', 'file', 'map', 'quote'])
  }))
};

function ChatForm(props) {
  var _useState = React.useState(props.message),
      _useState2 = slicedToArray(_useState, 2),
      message = _useState2[0],
      setMessage = _useState2[1];

  var _useState3 = React.useState([]),
      _useState4 = slicedToArray(_useState3, 2),
      files = _useState4[0],
      setFiles = _useState4[1];

  var _useState5 = React.useState(false),
      _useState6 = slicedToArray(_useState5, 2),
      fileOver = _useState6[0],
      setFileOver = _useState6[1];

  var formRef = React.useRef();

  React.useEffect(function () {
    formRef.current.addEventListener('drop', onDropFile);
    formRef.current.addEventListener('dragover', onDragOver);
    formRef.current.addEventListener('dragleave', onDragLeave);
    return function () {
      formRef.current.removeEventListener('drop', onDropFile);
      formRef.current.removeEventListener('dragover', onDragOver);
      formRef.current.removeEventListener('dragleave', onDragLeave);
    };
  }, [files]);

  var onDragOver = function onDragOver() {
    setFileOver(true);
  };
  var onDragLeave = function onDragLeave() {
    setFileOver(false);
  };

  var onDropFile = function onDropFile(e) {
    if (props.dropFiles) {
      e.preventDefault();
      e.stopPropagation();

      setFileOver(false);

      if (e.dataTransfer && e.dataTransfer.files) {
        var droppedFiles = [].concat(toConsumableArray(files));

        var _loop = function _loop(file) {
          var res = file;

          if (props.imgDropTypes.includes(file.type)) {
            var fr = new FileReader();
            fr.onload = function (event) {
              res.src = event.target.result;
              res.urlStyle = 'url(' + res.src + ')';
            };

            fr.readAsDataURL(file);
          }
          droppedFiles.push(res);
        };

        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
          for (var _iterator = e.dataTransfer.files[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var file = _step.value;

            _loop(file);
          }
        } catch (err) {
          _didIteratorError = true;
          _iteratorError = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }
          } finally {
            if (_didIteratorError) {
              throw _iteratorError;
            }
          }
        }

        setTimeout(function () {
          setFiles(droppedFiles);
        }, 500);
      }
    }
  };

  var removeFile = function removeFile(file) {
    var droppedFiles = [].concat(toConsumableArray(files));
    var index = droppedFiles.indexOf(file);
    if (index >= 0) {
      droppedFiles.splice(index, 1);
    }
    setFiles(droppedFiles);
  };

  var sendMessage = function sendMessage() {
    if (files.length || String(message).trim().length) {
      typeof props.onSend === 'function' && props.onSend({ message: message, files: files });
      setMessage('');
      setFiles([]);
    }
  };

  return React__default.createElement(
    'div',
    { className: 'form', ref: formRef },
    React__default.createElement(
      FormStyle,
      {
        fileOver: fileOver,
        buttonIcon: props.buttonIcon,
        showButton: props.showButton
      },
      React__default.createElement(
        'div',
        { className: 'dropped-files' },
        files.map(function (file, index) {
          return file.urlStyle ? React__default.createElement(
            'div',
            { key: index, style: { backgroundImage: file.urlStyle } },
            React__default.createElement(
              'span',
              { className: 'remove', onClick: function onClick() {
                  return removeFile(file);
                } },
              '\xD7'
            )
          ) : React__default.createElement(
            'div',
            { key: index, className: props.filesIcon },
            React__default.createElement(
              'span',
              { className: 'remove', onClick: function onClick() {
                  return removeFile(file);
                } },
              '\xD7'
            )
          );
        })
      ),
      React__default.createElement(
        'div',
        { className: 'message-row' },
        React__default.createElement('input', {
          type: 'text',
          value: message,
          onChange: function onChange(e) {
            return setMessage(e.target.value);
          },
          placeholder: fileOver ? props.fileOverPlaceholder : props.placeholder,
          onKeyUp: function onKeyUp(e) {
            e.preventDefault();
            if (e.key === 'Enter') {
              sendMessage();
            }
          }
        }),
        React__default.createElement(
          'button',
          { className: 'btn', onClick: sendMessage },
          props.buttonIcon ? React__default.createElement('span', { className: props.buttonIcon }) : props.buttonTitle
        )
      )
    )
  );
}
ChatForm.defaultProps = {
  imgDropTypes: ['image/png', 'image/jpeg', 'image/gif'],
  showButton: true,
  dropFiles: false,
  buttonTitle: 'Send',
  placeholder: 'Type a message',
  fileOverPlaceholder: 'Drop file to send'
};
ChatForm.propTypes = {
  imgDropTypes: propTypes.array,
  message: propTypes.string,
  buttonTitle: propTypes.string,
  buttonIcon: propTypes.string,
  showButton: propTypes.bool,
  dropFiles: propTypes.bool,
  onSend: propTypes.func,
  placeholder: propTypes.string,
  fileOverPlaceholder: propTypes.string,
  filesIcon: propTypes.string
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var badge = propTypes.shape({
  status: colorState,
  title: propTypes.string,
  position: position
});
var position = propTypes.oneOf(['topRight', 'topLeft', 'bottomRight', 'bottomLeft', 'topStart', 'topEnd', 'bottomStart', 'bottomEnd']);

var colorState = propTypes.oneOf(['Info', 'Success', 'Danger', 'Primary', 'Warning', 'Disabled', 'Active']);

var placement = propTypes.oneOf(['start', 'end', 'right', 'left', 'top', 'bottom']);

var trigger = propTypes.oneOf(['click', 'hover', 'focus', 'hint']);

var statusArray = ['Info', 'Success', 'Danger', 'Primary', 'Warning'];

var size = propTypes.oneOf(['XXS', 'XS', 'SM', 'MD', 'LG', 'XL', 'XXL']);

var shape = propTypes.oneOf(['Rectangle', 'SemiRound', 'Round']);
var customCss = {
  className: propTypes.string,
  style: propTypes.object
};
var itemType = {
  title: propTypes.string.isRequired,
  link: propTypes.any,
  expanded: propTypes.bool,
  group: propTypes.bool,
  hidden: propTypes.bool,
  icon: propTypes.string,
  target: propTypes.string,
  url: propTypes.string
};

var buttonTypes = {
  fullWidth: propTypes.bool,
  hero: propTypes.bool,
  outline: propTypes.bool,
  pulse: propTypes.bool,
  size: propTypes.oneOf(['XS', 'SM', 'MD', 'LG']),
  shape: shape,
  status: propTypes.oneOf([].concat(statusArray, ['Secondary']))
};

function Chat(props) {
  return React__default.createElement(
    ChatStyle,
    props,
    React__default.createElement(
      'header',
      null,
      props.title
    ),
    props.children
  );
}
Chat.defaultProps = {
  size: 'LG',
  status: 'Primary'
};
Chat.propTypes = {
  title: propTypes.string,
  size: size,
  status: colorState
};

exports.Chat = Chat;
exports.ChatMessages = Messages;
exports.ChatForm = ChatForm;
