'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var styled = require('styled-components');
var styled__default = _interopDefault(styled);

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
/* eslint-disable no-unused-vars */
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;

function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}

	return Object(val);
}

function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}

		// Detect buggy property enumeration order in older V8 versions.

		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}

		return true;
	} catch (err) {
		// We don't expect any of the above to throw, but better to be safe.
		return false;
	}
}

var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;

	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);

		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}

		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}

	return to;
};

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

var ReactPropTypesSecret_1 = ReactPropTypesSecret;

var printWarning = function() {};

if (process.env.NODE_ENV !== 'production') {
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};

  printWarning = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

/**
 * Assert that the values match with the type specs.
 * Error messages are memorized and will only be shown once.
 *
 * @param {object} typeSpecs Map of name to a ReactPropType
 * @param {object} values Runtime values that need to be type-checked
 * @param {string} location e.g. "prop", "context", "child context"
 * @param {string} componentName Name of the component for error messages.
 * @param {?Function} getStack Returns the component stack.
 * @private
 */
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  if (process.env.NODE_ENV !== 'production') {
    for (var typeSpecName in typeSpecs) {
      if (typeSpecs.hasOwnProperty(typeSpecName)) {
        var error;
        // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.
        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error(
              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'
            );
            err.name = 'Invariant Violation';
            throw err;
          }
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        if (error && !(error instanceof Error)) {
          printWarning(
            (componentName || 'React class') + ': type specification of ' +
            location + ' `' + typeSpecName + '` is invalid; the type checker ' +
            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
            'You may have forgotten to pass an argument to the type checker ' +
            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
            'shape all require an argument).'
          );

        }
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error.message] = true;

          var stack = getStack ? getStack() : '';

          printWarning(
            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
          );
        }
      }
    }
  }
}

var checkPropTypes_1 = checkPropTypes;

var printWarning$1 = function() {};

if (process.env.NODE_ENV !== 'production') {
  printWarning$1 = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

function emptyFunctionThatReturnsNull() {
  return null;
}

var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  /* global Symbol */
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

  /**
   * Returns the iterator method function contained on the iterable object.
   *
   * Be sure to invoke the function with the iterable as context:
   *
   *     var iteratorFn = getIteratorFn(myIterable);
   *     if (iteratorFn) {
   *       var iterator = iteratorFn.call(myIterable);
   *       ...
   *     }
   *
   * @param {?object} maybeIterable
   * @return {?function}
   */
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }

  /**
   * Collection of methods that allow declaration and validation of props that are
   * supplied to React components. Example usage:
   *
   *   var Props = require('ReactPropTypes');
   *   var MyArticle = React.createClass({
   *     propTypes: {
   *       // An optional string prop named "description".
   *       description: Props.string,
   *
   *       // A required enum prop named "category".
   *       category: Props.oneOf(['News','Photos']).isRequired,
   *
   *       // A prop named "dialog" that requires an instance of Dialog.
   *       dialog: Props.instanceOf(Dialog).isRequired
   *     },
   *     render: function() { ... }
   *   });
   *
   * A more formal specification of how these methods are used:
   *
   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
   *   decl := ReactPropTypes.{type}(.isRequired)?
   *
   * Each and every declaration produces a function with the same signature. This
   * allows the creation of custom validation functions. For example:
   *
   *  var MyLink = React.createClass({
   *    propTypes: {
   *      // An optional string or URI prop named "href".
   *      href: function(props, propName, componentName) {
   *        var propValue = props[propName];
   *        if (propValue != null && typeof propValue !== 'string' &&
   *            !(propValue instanceof URI)) {
   *          return new Error(
   *            'Expected a string or an URI for ' + propName + ' in ' +
   *            componentName
   *          );
   *        }
   *      }
   *    },
   *    render: function() {...}
   *  });
   *
   * @internal
   */

  var ANONYMOUS = '<<anonymous>>';

  // Important!
  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),

    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker,
    exact: createStrictShapeTypeChecker,
  };

  /**
   * inlined Object.is polyfill to avoid requiring consumers ship their own
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
   */
  /*eslint-disable no-self-compare*/
  function is(x, y) {
    // SameValue algorithm
    if (x === y) {
      // Steps 1-5, 7-10
      // Steps 6.b-6.e: +0 != -0
      return x !== 0 || 1 / x === 1 / y;
    } else {
      // Step 6.a: NaN == NaN
      return x !== x && y !== y;
    }
  }
  /*eslint-enable no-self-compare*/

  /**
   * We use an Error-like object for backward compatibility as people may call
   * PropTypes directly and inspect their output. However, we don't use real
   * Errors anymore. We don't inspect their stack anyway, and creating them
   * is prohibitively expensive if they are created too often, such as what
   * happens in oneOfType() for any type before the one that matched.
   */
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  // Make `instanceof Error` still work for returned errors.
  PropTypeError.prototype = Error.prototype;

  function createChainableTypeChecker(validate) {
    if (process.env.NODE_ENV !== 'production') {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;

      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          // New behavior only for users of `prop-types` package
          var err = new Error(
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
          err.name = 'Invariant Violation';
          throw err;
        } else if (process.env.NODE_ENV !== 'production' && typeof console !== 'undefined') {
          // Old behavior for people using React.PropTypes
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            // Avoid spamming the console because they are often not actionable except for lib authors
            manualPropTypeWarningCount < 3
          ) {
            printWarning$1(
              'You are manually calling a React.PropTypes validation ' +
              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }

    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);

    return chainedCheckType;
  }

  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        // `propValue` being instance of, say, date/regexp, pass the 'object'
        // check, but we can offer a more precise error message here rather than
        // 'of type `object`'.
        var preciseType = getPreciseType(propValue);

        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunctionThatReturnsNull);
  }

  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOf, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }

      var valuesString = JSON.stringify(expectedValues);
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + propValue + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (propValue.hasOwnProperty(key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOfType, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        printWarning$1(
          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
        );
        return emptyFunctionThatReturnsNull;
      }
    }

    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }

      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createStrictShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      // We need to check all keys in case some are required but missing from
      // props.
      var allKeys = objectAssign({}, props[propName], shapeTypes);
      for (var key in allKeys) {
        var checker = shapeTypes[key];
        if (!checker) {
          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
            '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
            '\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')
          );
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }

    return createChainableTypeChecker(validate);
  }

  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }

        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            // Iterator will provide entry [k,v] tuples rather than values.
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }

        return true;
      default:
        return false;
    }
  }

  function isSymbol(propType, propValue) {
    // Native Symbol.
    if (propType === 'symbol') {
      return true;
    }

    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }

    // Fallback for non-spec compliant Symbols which are polyfilled.
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }

    return false;
  }

  // Equivalent of `typeof` but with special handling for array and regexp.
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      // Old webkits (at least until Android 4.0) return 'function' rather than
      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
      // passes PropTypes.object.
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }

  // This handles more types than `getPropType`. Only used for error messages.
  // See `createPrimitiveTypeChecker`.
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }

  // Returns a string that is postfixed to a warning about an invalid type.
  // For example, "undefined" or "of type array"
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }

  // Returns class name of the object, if any.
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }

  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

function emptyFunction() {}

var factoryWithThrowingShims = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret_1) {
      // It is still safe when called from React.
      return;
    }
    var err = new Error(
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
    err.name = 'Invariant Violation';
    throw err;
  }  shim.isRequired = shim;
  function getShim() {
    return shim;
  }  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim,
    exact: getShim
  };

  ReactPropTypes.checkPropTypes = emptyFunction;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var propTypes = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

if (process.env.NODE_ENV !== 'production') {
  var REACT_ELEMENT_TYPE = (typeof Symbol === 'function' &&
    Symbol.for &&
    Symbol.for('react.element')) ||
    0xeac7;

  var isValidElement = function(object) {
    return typeof object === 'object' &&
      object !== null &&
      object.$$typeof === REACT_ELEMENT_TYPE;
  };

  // By explicitly using `prop-types` you are opting into new development behavior.
  // http://fb.me/prop-types-in-prod
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(isValidElement, throwOnDirectAccess);
} else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = factoryWithThrowingShims();
}
});

var slicedToArray = function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
}();

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

var _templateObject = taggedTemplateLiteral(['\n      @media (max-width: ', 'px) {\n        ', '\n      }\n    '], ['\n      @media (max-width: ', 'px) {\n        ', '\n      }\n    ']),
    _templateObject2 = taggedTemplateLiteral(['\n      @media (min-width: ', 'px) {\n        ', '\n      }\n    '], ['\n      @media (min-width: ', 'px) {\n        ', '\n      }\n    ']),
    _templateObject3 = taggedTemplateLiteral(['\n      @media (min-width: ', 'px) and (max-width: ', 'px) {\n        ', '\n      }\n    '], ['\n      @media (min-width: ', 'px) and (max-width: ', 'px) {\n        ', '\n      }\n    ']);
var breakpoints = {
  xs: 0,
  is: 400,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1400,
  xxxl: 1600
};
function breakpointMin(name) {
  return breakpoints[name] !== 0 ? breakpoints[name] : null;
}

function breakpointNext(index) {
  return index < Object.keys(breakpoints).length ? Object.keys(breakpoints)[index + 1] : null;
}

function breakpointMax(name) {
  var n = Object.keys(breakpoints).indexOf(name);
  var next = breakpointNext(n);
  return next ? breakpointMin(next) - 0.2 : null;
}

var breakpointDown = function breakpointDown(name) {
  return function () {
    var max = breakpointMax(name);
    if (max) {
      return styled.css(_templateObject, max, styled.css.apply(undefined, arguments));
    } else {
      return styled.css.apply(undefined, arguments);
    }
  };
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var _templateObject$1 = taggedTemplateLiteral(['\n  ', ';\n'], ['\n  ', ';\n']),
    _templateObject2$1 = taggedTemplateLiteral(['\n    font-family: ', ';\n    font-size: ', ';\n    font-weight: ', ';\n    background: ', ';\n    color: ', ';\n    display: block;\n    ul.menu-items {\n      margin: 0;\n      padding: 0;\n    }\n\n    .menu-group {\n      font-weight: ', ';\n      font-size: ', ';\n      color: ', ';\n      padding: ', ';\n    }\n\n    .menu-item {\n      a {\n        padding: ', ';\n        border-radius: ', ';\n      }\n\n      a:hover,\n      a.active {\n        background-color: ', ';\n        color: ', ';\n        font-weight: ', ';\n        .menu-icon {\n          color: ', ';\n        }\n        .chevron {\n          path {\n            fill: ', ';\n            stroke: ', ';\n          }\n        }\n      }\n\n      .menu-icon {\n        font-size: ', ';\n        width: auto;\n        margin: ', ';\n        text-align: center;\n        color: ', ';\n      }\n\n      .chevron {\n        path {\n          fill: ', ';\n          stroke: ', ';\n        }\n\n        ', '\n      }\n    }\n\n    .menu-items > .menu-item {\n      border-bottom: 1px solid ', ';\n      &:first-child {\n        border-top: 1px solid ', ';\n      }\n    }\n\n    .menu-item > .menu-items {\n      background-color: ', ';\n    }\n\n    .menu-item > .menu-items > .menu-item {\n      border: none;\n      background: ', ';\n      color: ', ';\n      padding: ', ';\n      &:first-child {\n        margin-top: ', ';\n      }\n      &:last-child {\n        margin-bottom: ', ';\n      }\n\n      a {\n        border: ', ';\n        padding: ', ';\n      }\n\n      a:hover {\n        color: ', ';\n        background: ', ';\n      }\n\n      a.active {\n        background-color: ', ';\n        color: ', ';\n        border-color: ', ';\n        box-shadow: none;\n        transition: all 300ms cubic-bezier(0.4, 0, 0.6, 1) 0ms;\n      }\n    }\n    .menu-items,\n    .menu-item > .menu-items {\n      list-style-type: none;\n      overflow: hidden;\n    }\n\n    .menu-item a {\n      display: flex;\n      color: inherit;\n      text-decoration: none;\n      align-items: center;\n\n      .menu-title {\n        flex: 1;\n        ', ';\n      }\n    }\n\n    &.inverse {\n      .menu-item {\n        a {\n          color: ', ';\n        }\n\n        a:hover {\n          background-color: ', ';\n          color: ', ';\n        }\n\n        a.active {\n          background-color: ', ';\n          color: ', ';\n        }\n      }\n\n      .menu-group {\n        color: ', ';\n      }\n    }\n  '], ['\n    font-family: ', ';\n    font-size: ', ';\n    font-weight: ', ';\n    background: ', ';\n    color: ', ';\n    display: block;\n    ul.menu-items {\n      margin: 0;\n      padding: 0;\n    }\n\n    .menu-group {\n      font-weight: ', ';\n      font-size: ', ';\n      color: ', ';\n      padding: ', ';\n    }\n\n    .menu-item {\n      a {\n        padding: ', ';\n        border-radius: ', ';\n      }\n\n      a:hover,\n      a.active {\n        background-color: ', ';\n        color: ', ';\n        font-weight: ', ';\n        .menu-icon {\n          color: ', ';\n        }\n        .chevron {\n          path {\n            fill: ', ';\n            stroke: ', ';\n          }\n        }\n      }\n\n      .menu-icon {\n        font-size: ', ';\n        width: auto;\n        margin: ', ';\n        text-align: center;\n        color: ', ';\n      }\n\n      .chevron {\n        path {\n          fill: ', ';\n          stroke: ', ';\n        }\n\n        ', '\n      }\n    }\n\n    .menu-items > .menu-item {\n      border-bottom: 1px solid ', ';\n      &:first-child {\n        border-top: 1px solid ', ';\n      }\n    }\n\n    .menu-item > .menu-items {\n      background-color: ', ';\n    }\n\n    .menu-item > .menu-items > .menu-item {\n      border: none;\n      background: ', ';\n      color: ', ';\n      padding: ', ';\n      &:first-child {\n        margin-top: ', ';\n      }\n      &:last-child {\n        margin-bottom: ', ';\n      }\n\n      a {\n        border: ', ';\n        padding: ', ';\n      }\n\n      a:hover {\n        color: ', ';\n        background: ', ';\n      }\n\n      a.active {\n        background-color: ', ';\n        color: ', ';\n        border-color: ', ';\n        box-shadow: none;\n        transition: all 300ms cubic-bezier(0.4, 0, 0.6, 1) 0ms;\n      }\n    }\n    .menu-items,\n    .menu-item > .menu-items {\n      list-style-type: none;\n      overflow: hidden;\n    }\n\n    .menu-item a {\n      display: flex;\n      color: inherit;\n      text-decoration: none;\n      align-items: center;\n\n      .menu-title {\n        flex: 1;\n        ', ';\n      }\n    }\n\n    &.inverse {\n      .menu-item {\n        a {\n          color: ', ';\n        }\n\n        a:hover {\n          background-color: ', ';\n          color: ', ';\n        }\n\n        a.active {\n          background-color: ', ';\n          color: ', ';\n        }\n      }\n\n      .menu-group {\n        color: ', ';\n      }\n    }\n  ']),
    _templateObject3$1 = taggedTemplateLiteral(['\n  ul {\n    &.expanded {\n      max-height: 1500px;\n      transition: max-height 0.5s cubic-bezier(1, 0.15, 1, 1);\n    }\n\n    &.collapsed {\n      max-height: 0;\n      transition: max-height 0.5s cubic-bezier(0, 1, 0.3, 1) -100ms;\n    }\n  }\n'], ['\n  ul {\n    &.expanded {\n      max-height: 1500px;\n      transition: max-height 0.5s cubic-bezier(1, 0.15, 1, 1);\n    }\n\n    &.collapsed {\n      max-height: 0;\n      transition: max-height 0.5s cubic-bezier(0, 1, 0.3, 1) -100ms;\n    }\n  }\n']);

var MenuStyle = styled__default.div(_templateObject$1, function (_ref) {
  var theme = _ref.theme;
  return styled.css(_templateObject2$1, theme.menuFontFamily, theme.menuFontSize, theme.menuFontWeight, theme.menuBg, theme.menuFg, theme.menuGroupFontWeight, theme.menuGroupFontSize, theme.menuGroupFg, theme.menuGroupPadding, theme.menuItemPadding, theme.menuSubmenuItemBorderRadius, theme.menuActiveBg, theme.menuActiveFg, theme.menuActiveFontWeight, theme.menuIconActiveColor, theme.menuIconActiveColor, theme.menuIconActiveColor, theme.menuIconFontSize, theme.menuIconMargin, theme.menuIconColor, theme.menuIconColor, theme.menuIconColor, theme.dir === 'rtl' && 'transform: rotateY(180deg);', theme.menuItemSeparator, theme.menuItemSeparator, theme.menuSubmenuBg, theme.menuSubmenuBg, theme.menuSubmenuFg, theme.menuSubmenuItemContainerPadding, theme.menuSubmenuPadding, theme.menuSubmenuPadding, theme.menuSubmenuItemBorderWidth + ' solid ' + theme.menuSubmenuBg, theme.menuSubmenuItemPadding, theme.menuSubmenuHoverFg, theme.menuSubmenuHoverBg, theme.menuSubmenuActiveBg, theme.menuSubmenuActiveFg, theme.menuSubmenuActiveBorderColor, theme.dir === 'rtl' ? 'text-align: right' : '', theme.menuBg, theme.menuActiveFg, theme.menuActiveBg, theme.menuActiveFg, theme.menuActiveBg, theme.menuBg);
});
var ItemStyle = styled__default.li(_templateObject3$1);

var _templateObject$2 = taggedTemplateLiteral(['\n  ', ' {\n    width: ', ';\n\n    .menu-item a.active {\n      position: relative;\n\n      &::before {\n        position: absolute;\n        content: \'\';\n        ', '\n        top: 0;\n        height: 100%;\n        width: 4px;\n        background: ', ';\n      }\n    }\n\n    > .menu-items > .menu-item > a {\n      span,\n      .chevron {\n        display: none;\n      }\n    }\n\n    .menu-items > .menu-item {\n      transition: border-color 1s ease;\n\n      &.menu-group {\n        display: block;\n        color: transparent;\n        width: 0;\n        padding: 0;\n        overflow: hidden;\n      }\n\n      i {\n        margin-right: 0;\n      }\n\n      a {\n        justify-content: center;\n      }\n\n      & > .expanded {\n        display: none;\n      }\n    }\n  }\n  ', '\n'], ['\n  ', ' {\n    width: ', ';\n\n    .menu-item a.active {\n      position: relative;\n\n      &::before {\n        position: absolute;\n        content: \'\';\n        ', '\n        top: 0;\n        height: 100%;\n        width: 4px;\n        background: ', ';\n      }\n    }\n\n    > .menu-items > .menu-item > a {\n      span,\n      .chevron {\n        display: none;\n      }\n    }\n\n    .menu-items > .menu-item {\n      transition: border-color 1s ease;\n\n      &.menu-group {\n        display: block;\n        color: transparent;\n        width: 0;\n        padding: 0;\n        overflow: hidden;\n      }\n\n      i {\n        margin-right: 0;\n      }\n\n      a {\n        justify-content: center;\n      }\n\n      & > .expanded {\n        display: none;\n      }\n    }\n  }\n  ', '\n']),
    _templateObject2$2 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject3$2 = taggedTemplateLiteral(['\n    position: fixed;\n    height: 100%;\n    z-index: 999;\n    top: ', ';\n    bottom: 0;\n    ', '\n    ', '\n  '], ['\n    position: fixed;\n    height: 100%;\n    z-index: 999;\n    top: ', ';\n    bottom: 0;\n    ', '\n    ', '\n  ']),
    _templateObject4 = taggedTemplateLiteral(['\n  font-size: ', ';\n  font-weight: ', ';\n  box-shadow: ', ';\n  display: flex;\n  flex-direction: column;\n  overflow: hidden;\n  z-index: auto;\n  transition: width .3s cubic-bezier(0.4, 0, 0.6, 1) 0ms;\n\n  order: ', ';\n    \n  ', '\n  .main-container {\n    ', '\n    height: ', ';\n    background: ', ';\n    transform: translate3d(0, 0, 0);\n    display: flex;\n    flex-direction: column;\n    transition: width .3s cubic-bezier(0.4, 0, 0.6, 1) 0ms;\n    ', '\n  }\n\n  .scrollable {\n    ', '\n    flex: 1;\n    position: relative;\n    -webkit-transform: translate3d(0, 0, 0);\n    ', '\n  }\n  \n  ', '\n\n  ', '\n\n\n  header,\n  footer\n   {\n     ', '\n    display: block;\n    \n  }\n\n  header{\n    height: ', ';\n  }\n\n  footer {\n    margin-top: auto;\n    height: ', ';\n  }\n\n  ', '{\n    margin: 0 -', ' -', ';\n  }\n'], ['\n  font-size: ', ';\n  font-weight: ', ';\n  box-shadow: ', ';\n  display: flex;\n  flex-direction: column;\n  overflow: hidden;\n  z-index: auto;\n  transition: width .3s cubic-bezier(0.4, 0, 0.6, 1) 0ms;\n\n  order: ', ';\n    \n  ', '\n  .main-container {\n    ', '\n    height: ', ';\n    background: ', ';\n    transform: translate3d(0, 0, 0);\n    display: flex;\n    flex-direction: column;\n    transition: width .3s cubic-bezier(0.4, 0, 0.6, 1) 0ms;\n    ', '\n  }\n\n  .scrollable {\n    ', '\n    flex: 1;\n    position: relative;\n    -webkit-transform: translate3d(0, 0, 0);\n    ', '\n  }\n  \n  ', '\n\n  ', '\n\n\n  header,\n  footer\n   {\n     ', '\n    display: block;\n    \n  }\n\n  header{\n    height: ', ';\n  }\n\n  footer {\n    margin-top: auto;\n    height: ', ';\n  }\n\n  ', '{\n    margin: 0 -', ' -', ';\n  }\n']),
    _templateObject5 = taggedTemplateLiteral(['\n      overflow-y: scroll;\n      -webkit-overflow-scrolling: touch;\n      '], ['\n      overflow-y: scroll;\n      -webkit-overflow-scrolling: touch;\n      ']);
/* eslint-disable indent */

var compacted = styled.css(_templateObject$2, MenuStyle, function (_ref) {
  var theme = _ref.theme;
  return theme.sidebarWidthCompact;
}, function (_ref2) {
  var theme = _ref2.theme;
  return theme.dir === 'rtl' ? 'right: 0;' : 'left: 0;';
}, function (_ref3) {
  var theme = _ref3.theme;
  return theme.colorFgHighlight;
}, function (_ref4) {
  var property = _ref4.property,
      theme = _ref4.theme,
      fixed = _ref4.fixed;

  if (fixed) {
    switch (property) {
      case 'right':
        return '\n          & ~ .content {\n            margin-right: ' + theme.sidebarWidthCompact + ';\n          }\n          & ~ .content.center {\n            padding-right: ' + theme.sidebarWidthCompact + ';\n          }\n        ';
      case 'left':
        return '\n          & ~ .content {\n            margin-left: ' + theme.sidebarWidthCompact + ';\n          }\n          & ~ .content.center {\n            padding-left: ' + theme.sidebarWidthCompact + ';\n          }\n        ';
      case 'start':
        return '\n          & ~ .content {\n            ' + (theme.dir == 'rtl' ? 'margin-right:' : 'margin-left:') + ' ' + theme.sidebarWidthCompact + ';\n          }\n          & ~ .content.center {\n            ' + (theme.dir == 'rtl' ? 'padding-right:' : 'padding-left:') + ' ' + theme.sidebarWidthCompact + ';\n          }\n        ';
      case 'end':
        return '\n          & ~ .content {\n            ' + (theme.dir == 'rtl' ? 'margin-left:' : 'margin-right:') + ' ' + theme.sidebarWidthCompact + ';\n          }\n          & ~ .content.center {\n            ' + (theme.dir == 'rtl' ? 'padding-left:' : 'padding-right:') + ' ' + theme.sidebarWidthCompact + ';\n          }\n        ';
      default:
        break;
    }
  }
});

var fixedStyle = styled.css(_templateObject2$2, function (_ref5) {
  var theme = _ref5.theme,
      property = _ref5.property,
      state = _ref5.state;
  return styled.css(_templateObject3$2, theme.headerHeight, state === 'hidden' && ['left', 'start'].includes(property) ? '\n        & + .content {\n          margin-left: 0;\n        }\n      ' : state === 'hidden' && ['right', 'end'].includes(property) ? '\n        & + .content {\n          margin-right: 0;\n        }\n      ' : '', property === 'right' ? 'right: 0;' : property === 'left' ? 'left: 0;' : property === 'start' ? theme.dir == 'rtl' ? 'right: 0;' : 'left: 0;' : property === 'end' ? theme.dir == 'rtl' ? 'left: 0;' : 'right: 0;' : '');
});

var SidebarStyle = styled__default.aside(_templateObject2$2, function (_ref6) {
  var theme = _ref6.theme,
      property = _ref6.property,
      state = _ref6.state,
      containerFixed = _ref6.containerFixed,
      fixed = _ref6.fixed;
  return styled.css(_templateObject4, theme.sidebarFontSize, theme.sidebarFontWeight, theme.sidebarShadow, property === 'right' ? theme.dir == 'rtl' ? '0' : '4' : property === 'left' ? theme.dir == 'rtl' ? '4' : '0' : property === 'end' ? '4' : '0', state === 'hidden' ? 'width: 0;padding: 0;' : state === 'compacted' ? 'width: ' + theme.sidebarWidthCompact + ';' : 'width: ' + theme.sidebarWidth + ';', state === 'hidden' ? 'width: 0;padding: 0;' : state === 'compacted' ? 'width: ' + theme.sidebarWidthCompact + ';' : 'width: ' + theme.sidebarWidth + ';', theme.sidebarHeight, theme.sidebarBg, containerFixed && 'position: fixed;', state === 'hidden' ? 'width: 0;padding: 0;overflow: hidden;' : 'overflow-y: auto;overflow-x: hidden;padding: ' + theme.sidebarPadding + ';', breakpointDown('sm')(_templateObject5), fixed && fixedStyle, state === 'compacted' && compacted, state === 'hidden' ? 'width: 0;padding: 0;overflow: hidden;' : 'padding: ' + theme.sidebarPadding + ';', theme.sidebarHeaderHeight, theme.sidebarFooterHeight, MenuStyle, theme.sidebarPadding, theme.sidebarPadding);
});

var _templateObject$3 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2$3 = taggedTemplateLiteral(['\n      text-align: ', ';\n      -webkit-font-smoothing: antialiased;\n      .layout {\n        display: flex;\n        flex-direction: column;\n        min-width: ', ';\n        font-family: ', ';\n        font-size: ', ';\n        line-height: ', ';\n        color: ', ';\n        background: ', ';\n        min-height: ', ';\n      }\n\n      ', '\n      ', '\n\n      ', '\n      #overlay-container {\n        position: fixed;\n        z-index: 1040;\n        pointer-events: none;\n        top: 0;\n        left: 0;\n        height: 100%;\n        width: 100%;\n      }\n    '], ['\n      text-align: ', ';\n      -webkit-font-smoothing: antialiased;\n      .layout {\n        display: flex;\n        flex-direction: column;\n        min-width: ', ';\n        font-family: ', ';\n        font-size: ', ';\n        line-height: ', ';\n        color: ', ';\n        background: ', ';\n        min-height: ', ';\n      }\n\n      ', '\n      ', '\n\n      ', '\n      #overlay-container {\n        position: fixed;\n        z-index: 1040;\n        pointer-events: none;\n        top: 0;\n        left: 0;\n        height: 100%;\n        width: 100%;\n      }\n    ']),
    _templateObject3$3 = taggedTemplateLiteral(['\n            .scrollable-container {\n              overflow: auto;\n              height: 100vh;\n              display: block;\n              ', '\n            }\n          '], ['\n            .scrollable-container {\n              overflow: auto;\n              height: 100vh;\n              display: block;\n              ', '\n            }\n          ']),
    _templateObject4$1 = taggedTemplateLiteral(['\n            overflow-y: scroll;\n            -webkit-overflow-scrolling: touch;\n          '], ['\n            overflow-y: scroll;\n            -webkit-overflow-scrolling: touch;\n          ']),
    _templateObject5$1 = taggedTemplateLiteral(['\n          background: ', ';\n          display: block;\n          .scrollable-container {\n            max-width: ', ';\n            margin: 0 auto;\n          }\n\n          .layout ', ' nav {\n            max-width: ', ';\n            margin: 0 auto;\n          }\n\n          @media screen and (min-width: ', ' + 20px) {\n            ', '\n\n            ', '.with-scroll {\n              .scrollable-container {\n                height: calc(100vh - ', ');\n              }\n            }\n          }\n          @media screen and (min-width: ', ' + 150px) {\n            ', '\n\n            ', '.with-scroll {\n              .scrollable-container {\n                height: calc(100vh - ', ');\n              }\n            }\n          }\n          @media screen and (min-width: ', ' + 300px) {\n            ', '\n\n            ', '.with-scroll {\n              .scrollable-container {\n                height: calc(100vh - ', ');\n              }\n            }\n          }\n        '], ['\n          background: ', ';\n          display: block;\n          .scrollable-container {\n            max-width: ', ';\n            margin: 0 auto;\n          }\n\n          .layout ', ' nav {\n            max-width: ', ';\n            margin: 0 auto;\n          }\n\n          @media screen and (min-width: ', ' + 20px) {\n            ', '\n\n            ', '.with-scroll {\n              .scrollable-container {\n                height: calc(100vh - ', ');\n              }\n            }\n          }\n          @media screen and (min-width: ', ' + 150px) {\n            ', '\n\n            ', '.with-scroll {\n              .scrollable-container {\n                height: calc(100vh - ', ');\n              }\n            }\n          }\n          @media screen and (min-width: ', ' + 300px) {\n            ', '\n\n            ', '.with-scroll {\n              .scrollable-container {\n                height: calc(100vh - ', ');\n              }\n            }\n          }\n        ']),
    _templateObject6 = taggedTemplateLiteral(['\n          ', ' .main-container {\n            box-shadow: none;\n          }\n        '], ['\n          ', ' .main-container {\n            box-shadow: none;\n          }\n        ']),
    _templateObject7 = taggedTemplateLiteral(['\n    padding-top: calc(', ' / ', ');\n\n    ', '.fixed {\n      left: calc((100vw - ', ') / 2);\n    }\n\n    .layout ', ' {\n      ', '.fixed.right {\n        right: calc((100vw - ', ') / 2);\n      }\n\n      ', '.fixed {\n        top: calc(', ' + calc(', ' / ', '));\n      }\n    }\n\n    .scrollable-container {\n      height: calc(100vh - calc(', ' / ', '));\n      box-shadow: ', ';\n    }\n  '], ['\n    padding-top: calc(', ' / ', ');\n\n    ', '.fixed {\n      left: calc((100vw - ', ') / 2);\n    }\n\n    .layout ', ' {\n      ', '.fixed.right {\n        right: calc((100vw - ', ') / 2);\n      }\n\n      ', '.fixed {\n        top: calc(', ' + calc(', ' / ', '));\n      }\n    }\n\n    .scrollable-container {\n      height: calc(100vh - calc(', ' / ', '));\n      box-shadow: ', ';\n    }\n  ']),
    _templateObject8 = taggedTemplateLiteral(['\n  display: flex;\n  flex: 1;\n  flex-direction: row;\n'], ['\n  display: flex;\n  flex: 1;\n  flex-direction: row;\n']),
    _templateObject9 = taggedTemplateLiteral(['\n    display: flex;\n    flex: 1;\n    flex-direction: column;\n    min-width: 0;\n    ', '\n  '], ['\n    display: flex;\n    flex: 1;\n    flex-direction: column;\n    min-width: 0;\n    ', '\n  ']),
    _templateObject10 = taggedTemplateLiteral(['\n        max-width: 100%;\n        position: relative;\n        margin-left: auto;\n        margin-right: auto;\n        width: ', ';\n        flex: 0 100 ', ' !important;\n      '], ['\n        max-width: 100%;\n        position: relative;\n        margin-left: auto;\n        margin-right: auto;\n        width: ', ';\n        flex: 0 100 ', ' !important;\n      ']),
    _templateObject11 = taggedTemplateLiteral(['\n  display: flex;\n  flex: 1;\n  flex-direction: row;\n  width: 100%;\n'], ['\n  display: flex;\n  flex: 1;\n  flex-direction: row;\n  width: 100%;\n']),
    _templateObject12 = taggedTemplateLiteral(['\n    order: 1;\n    flex: 1 0;\n    min-width: 0;\n    padding: ', ';\n\n    ', '\n\n    ', '\n\n    ', '\n  '], ['\n    order: 1;\n    flex: 1 0;\n    min-width: 0;\n    padding: ', ';\n\n    ', '\n\n    ', '\n\n    ', '\n  ']),
    _templateObject13 = taggedTemplateLiteral(['padding: ', ';'], ['padding: ', ';']),
    _templateObject14 = taggedTemplateLiteral(['\n    font-family: ', ';\n    font-size: ', ';\n    line-height: ', ';\n    display: block;\n    nav {\n      box-shadow: ', ';\n      height: ', ';\n      padding: ', ';\n      background: ', ';\n      color: ', ';\n      align-items: center;\n      justify-content: flex-start;\n      display: flex;\n      a {\n        color: ', ';\n        &:hover,\n        &:focus,\n        &:active {\n          color: ', ';\n        }\n      }\n    }\n    & ~ ', ' {\n      min-height: calc(', ');\n    }\n\n    ', '\n  '], ['\n    font-family: ', ';\n    font-size: ', ';\n    line-height: ', ';\n    display: block;\n    nav {\n      box-shadow: ', ';\n      height: ', ';\n      padding: ', ';\n      background: ', ';\n      color: ', ';\n      align-items: center;\n      justify-content: flex-start;\n      display: flex;\n      a {\n        color: ', ';\n        &:hover,\n        &:focus,\n        &:active {\n          color: ', ';\n        }\n      }\n    }\n    & ~ ', ' {\n      min-height: calc(', ');\n    }\n\n    ', '\n  ']),
    _templateObject15 = taggedTemplateLiteral(['\n        position: fixed;\n        left: 0;\n        right: 0;\n        z-index: 1040;\n        & ~ ', ' {\n          padding-top: ', ';\n          min-height: ', ';\n        }\n        ~ ', ' > aside > .main-container {\n          height: calc(', ');\n        }\n      '], ['\n        position: fixed;\n        left: 0;\n        right: 0;\n        z-index: 1040;\n        & ~ ', ' {\n          padding-top: ', ';\n          min-height: ', ';\n        }\n        ~ ', ' > aside > .main-container {\n          height: calc(', ');\n        }\n      ']),
    _templateObject16 = taggedTemplateLiteral(['\n    display: block;\n    margin-top: auto;\n    box-shadow: ', ';\n    nav {\n      justify-content: center;\n      display: flex;\n      padding: ', ';\n      background: ', ';\n      color: ', ';\n      border-top: 1px solid ', ';\n      a {\n        color: ', ';\n        &:hover,\n        &:focus,\n        &:active {\n          color: ', ';\n        }\n      }\n    }\n  '], ['\n    display: block;\n    margin-top: auto;\n    box-shadow: ', ';\n    nav {\n      justify-content: center;\n      display: flex;\n      padding: ', ';\n      background: ', ';\n      color: ', ';\n      border-top: 1px solid ', ';\n      a {\n        color: ', ';\n        &:hover,\n        &:focus,\n        &:active {\n          color: ', ';\n        }\n      }\n    }\n  ']);

var LayoutStyle = styled__default.div(_templateObject$3, function (_ref) {
  var theme = _ref.theme,
      withScroll = _ref.withScroll,
      windowMode = _ref.windowMode,
      withSubHeader = _ref.withSubHeader;

  var windowPadding = theme.layoutWindowModePaddingTop;
  return styled.css(_templateObject2$3, theme.dir === 'rtl' ? 'right' : 'left', theme.layoutWindowModeMinWidth, theme.layoutFontFamily, theme.layoutFontSize, theme.layoutLineHeight, theme.layoutFg, theme.layoutBg, theme.layoutMinHeight, withScroll || windowMode && styled.css(_templateObject3$3, breakpointDown('sm')(_templateObject4$1)), windowMode && styled.css(_templateObject5$1, theme.layoutWindowModeBg, theme.layoutWindowModeMaxWidth, HeaderStyle, theme.layoutWindowModeMaxWidth, theme.layoutWindowModeMaxWidth, getWindowMode(theme, windowPadding, 4), LayoutStyle, windowPadding, theme.layoutWindowModeMaxWidth, getWindowMode(theme, windowPadding, 2), LayoutStyle, windowPadding, theme.layoutWindowModeMaxWidth, getWindowMode(theme, windowPadding, 1), LayoutStyle, windowPadding), withSubHeader && styled.css(_templateObject6, SidebarStyle));
});

var getWindowMode = function getWindowMode(theme, padding, action) {
  return styled.css(_templateObject7, padding, action, SidebarStyle, theme.layoutWindowModeMaxWidth, LayoutContainer, SidebarStyle, theme.layoutWindowModeMaxWidth, SidebarStyle, theme.headerHeight, padding, action, padding, action, theme.layoutWindowShadow);
};

var LayoutContainer = styled__default.div(_templateObject8);

var LayoutContent = styled__default.div(_templateObject$3, function (_ref2) {
  var theme = _ref2.theme,
      center = _ref2.center;
  return styled.css(_templateObject9, center && styled.css(_templateObject10, theme.layoutContentWidth, theme.layoutContentWidth));
});

var LayoutColumns = styled__default.div(_templateObject11);

var LayoutColumn = styled__default.div(_templateObject$3, function (_ref3) {
  var theme = _ref3.theme,
      position = _ref3.position;
  return styled.css(_templateObject12, theme.layoutPadding, position === 'left' ? theme.dir === 'rtl' ? 'order: 2;' : 'order: 0;' : position === 'start' && 'order: 0;', breakpointDown('md')(_templateObject13, theme.layoutMediumPadding), breakpointDown('sm')(_templateObject13, theme.layoutSmallPadding));
});

LayoutColumn.propTypes = {
  position: propTypes.oneOf(['start', 'left'])
};

var HeaderStyle = styled__default.header(_templateObject$3, function (_ref4) {
  var theme = _ref4.theme,
      fixed = _ref4.fixed;
  return styled.css(_templateObject14, theme.headerFontFamily, theme.headerFontSize, theme.headerLineHeight, theme.headerShadow, theme.headerHeight, theme.headerPadding, theme.headerBg, theme.headerFg, theme.headerFg, theme.headerFg, LayoutContainer, theme.layoutMinHeight + ' - ' + theme.headerHeight, fixed && styled.css(_templateObject15, LayoutContainer, theme.headerHeight, theme.layoutMinHeight, LayoutContainer, theme.sidebarHeight + ' - ' + theme.headerHeight));
});

var FooterStyle = styled__default.footer(_templateObject$3, function (_ref5) {
  var theme = _ref5.theme;
  return styled.css(_templateObject16, theme.footerShadow, theme.footerPadding, theme.footerBg, theme.footerFg, theme.footerSeparator, theme.footerFgHighlight, theme.footerFgHighlight);
});

var layoutContext = React__default.createContext({
  addClass: function addClass() {},
  removeClass: function removeClass() {},
  addEventListener: function addEventListener() {},
  removeEventListener: function removeEventListener() {},
  dir: 'ltr'
});

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

function LayoutHeader(props) {
  return React__default.createElement(
    HeaderStyle,
    props,
    React__default.createElement(
      'nav',
      null,
      props.children
    )
  );
}
LayoutHeader.propTypes = {
  fixed: propTypes.bool
};
function LayoutFooter(props) {
  return React__default.createElement(
    FooterStyle,
    props,
    React__default.createElement(
      'nav',
      null,
      props.children
    )
  );
}

function Layout(props) {
  var _useState = React.useState(props.className ? [].concat(toConsumableArray(props.className.split(' '))) : []),
      _useState2 = slicedToArray(_useState, 2),
      className = _useState2[0],
      setClassName = _useState2[1];

  var scrollRef = React.useRef();

  React.useEffect(function () {
    if ((props.withScroll || props.windowMode) && !className.includes('with-scroll')) {
      addClass(['with-scroll']);
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'initial';
    }
  }, [props.withScroll]);

  var addClass = function addClass(cssClass) {
    var updatedClass = [].concat(toConsumableArray(className));
    updatedClass.push.apply(updatedClass, toConsumableArray(cssClass));
    setClassName(updatedClass);
  };

  var removeClass = function removeClass(cssClass) {
    var updatedClass = [].concat(toConsumableArray(className));
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = updatedClass.keys()[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var i = _step.value;

        if (cssClass.includes(updatedClass[i])) {
          updatedClass.splice(i, 1);
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    setClassName(updatedClass);
  };

  var addEventListener = function addEventListener(event, listener) {
    var target = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'scrollArea';

    switch (target) {
      case 'Layout':
        document.getElementById('oah-layout').addEventListener(event, listener);
        break;

      default:
        if (props.withScroll || props.windowMode) {
          scrollRef.current.addEventListener(event, listener);
        } else {
          window.addEventListener(event, listener);
        }
        break;
    }
  };
  var removeEventListener = function removeEventListener(event, listener) {
    var target = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'scrollArea';

    switch (target) {
      case 'Layout':
        document.getElementById('oah-layout').removeEventListener(event, listener);
        break;

      default:
        if (props.withScroll || props.windowMode) {
          scrollRef.current.removeEventListener(event, listener);
        } else {
          window.removeEventListener(event, listener);
        }
        break;
    }
  };

  return React__default.createElement(
    LayoutStyle,
    {
      id: 'oah-layout',
      className: className.join(' '),
      style: props.style,
      withScroll: props.withScroll,
      windowMode: props.windowMode,
      withSubHeader: props.withSubHeader
    },
    React__default.createElement(
      layoutContext.Provider,
      {
        value: {
          addClass: addClass,
          removeClass: removeClass,
          removeEventListener: removeEventListener,
          addEventListener: addEventListener,
          dir: props.dir
        }
      },
      React__default.createElement(
        'div',
        { ref: scrollRef, className: 'scrollable-container' },
        React__default.createElement(
          'div',
          { className: 'layout' },
          props.children
        )
      ),
      React__default.createElement('div', { id: 'overlay-container' })
    )
  );
}
Layout.defaultProps = {
  dir: 'ltr'
};

Layout.propTypes = {
  dir: propTypes.oneOf(['ltr', 'rtl']),
  className: propTypes.string,
  style: propTypes.object,
  withScroll: propTypes.bool,
  windowMode: propTypes.bool,
  withSubHeader: propTypes.bool
};

exports.Layout = Layout;
exports.LayoutHeader = LayoutHeader;
exports.LayoutContent = LayoutContent;
exports.LayoutFooter = LayoutFooter;
exports.LayoutContainer = LayoutContainer;
exports.LayoutColumns = LayoutColumns;
exports.LayoutColumn = LayoutColumn;
exports.LayoutStyle = LayoutStyle;
exports.LayoutContext = layoutContext;
