'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var ReactDOM = _interopDefault(require('react-dom'));

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
/* eslint-disable no-unused-vars */
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;

function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}

	return Object(val);
}

function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}

		// Detect buggy property enumeration order in older V8 versions.

		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}

		return true;
	} catch (err) {
		// We don't expect any of the above to throw, but better to be safe.
		return false;
	}
}

var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;

	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);

		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}

		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}

	return to;
};

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

var ReactPropTypesSecret_1 = ReactPropTypesSecret;

var printWarning = function() {};

if (process.env.NODE_ENV !== 'production') {
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};

  printWarning = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

/**
 * Assert that the values match with the type specs.
 * Error messages are memorized and will only be shown once.
 *
 * @param {object} typeSpecs Map of name to a ReactPropType
 * @param {object} values Runtime values that need to be type-checked
 * @param {string} location e.g. "prop", "context", "child context"
 * @param {string} componentName Name of the component for error messages.
 * @param {?Function} getStack Returns the component stack.
 * @private
 */
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  if (process.env.NODE_ENV !== 'production') {
    for (var typeSpecName in typeSpecs) {
      if (typeSpecs.hasOwnProperty(typeSpecName)) {
        var error;
        // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.
        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error(
              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'
            );
            err.name = 'Invariant Violation';
            throw err;
          }
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        if (error && !(error instanceof Error)) {
          printWarning(
            (componentName || 'React class') + ': type specification of ' +
            location + ' `' + typeSpecName + '` is invalid; the type checker ' +
            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
            'You may have forgotten to pass an argument to the type checker ' +
            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
            'shape all require an argument).'
          );

        }
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error.message] = true;

          var stack = getStack ? getStack() : '';

          printWarning(
            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
          );
        }
      }
    }
  }
}

var checkPropTypes_1 = checkPropTypes;

var printWarning$1 = function() {};

if (process.env.NODE_ENV !== 'production') {
  printWarning$1 = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

function emptyFunctionThatReturnsNull() {
  return null;
}

var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  /* global Symbol */
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

  /**
   * Returns the iterator method function contained on the iterable object.
   *
   * Be sure to invoke the function with the iterable as context:
   *
   *     var iteratorFn = getIteratorFn(myIterable);
   *     if (iteratorFn) {
   *       var iterator = iteratorFn.call(myIterable);
   *       ...
   *     }
   *
   * @param {?object} maybeIterable
   * @return {?function}
   */
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }

  /**
   * Collection of methods that allow declaration and validation of props that are
   * supplied to React components. Example usage:
   *
   *   var Props = require('ReactPropTypes');
   *   var MyArticle = React.createClass({
   *     propTypes: {
   *       // An optional string prop named "description".
   *       description: Props.string,
   *
   *       // A required enum prop named "category".
   *       category: Props.oneOf(['News','Photos']).isRequired,
   *
   *       // A prop named "dialog" that requires an instance of Dialog.
   *       dialog: Props.instanceOf(Dialog).isRequired
   *     },
   *     render: function() { ... }
   *   });
   *
   * A more formal specification of how these methods are used:
   *
   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
   *   decl := ReactPropTypes.{type}(.isRequired)?
   *
   * Each and every declaration produces a function with the same signature. This
   * allows the creation of custom validation functions. For example:
   *
   *  var MyLink = React.createClass({
   *    propTypes: {
   *      // An optional string or URI prop named "href".
   *      href: function(props, propName, componentName) {
   *        var propValue = props[propName];
   *        if (propValue != null && typeof propValue !== 'string' &&
   *            !(propValue instanceof URI)) {
   *          return new Error(
   *            'Expected a string or an URI for ' + propName + ' in ' +
   *            componentName
   *          );
   *        }
   *      }
   *    },
   *    render: function() {...}
   *  });
   *
   * @internal
   */

  var ANONYMOUS = '<<anonymous>>';

  // Important!
  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),

    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker,
    exact: createStrictShapeTypeChecker,
  };

  /**
   * inlined Object.is polyfill to avoid requiring consumers ship their own
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
   */
  /*eslint-disable no-self-compare*/
  function is(x, y) {
    // SameValue algorithm
    if (x === y) {
      // Steps 1-5, 7-10
      // Steps 6.b-6.e: +0 != -0
      return x !== 0 || 1 / x === 1 / y;
    } else {
      // Step 6.a: NaN == NaN
      return x !== x && y !== y;
    }
  }
  /*eslint-enable no-self-compare*/

  /**
   * We use an Error-like object for backward compatibility as people may call
   * PropTypes directly and inspect their output. However, we don't use real
   * Errors anymore. We don't inspect their stack anyway, and creating them
   * is prohibitively expensive if they are created too often, such as what
   * happens in oneOfType() for any type before the one that matched.
   */
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  // Make `instanceof Error` still work for returned errors.
  PropTypeError.prototype = Error.prototype;

  function createChainableTypeChecker(validate) {
    if (process.env.NODE_ENV !== 'production') {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;

      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          // New behavior only for users of `prop-types` package
          var err = new Error(
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
          err.name = 'Invariant Violation';
          throw err;
        } else if (process.env.NODE_ENV !== 'production' && typeof console !== 'undefined') {
          // Old behavior for people using React.PropTypes
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            // Avoid spamming the console because they are often not actionable except for lib authors
            manualPropTypeWarningCount < 3
          ) {
            printWarning$1(
              'You are manually calling a React.PropTypes validation ' +
              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }

    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);

    return chainedCheckType;
  }

  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        // `propValue` being instance of, say, date/regexp, pass the 'object'
        // check, but we can offer a more precise error message here rather than
        // 'of type `object`'.
        var preciseType = getPreciseType(propValue);

        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunctionThatReturnsNull);
  }

  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOf, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }

      var valuesString = JSON.stringify(expectedValues);
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + propValue + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (propValue.hasOwnProperty(key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOfType, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        printWarning$1(
          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
        );
        return emptyFunctionThatReturnsNull;
      }
    }

    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }

      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createStrictShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      // We need to check all keys in case some are required but missing from
      // props.
      var allKeys = objectAssign({}, props[propName], shapeTypes);
      for (var key in allKeys) {
        var checker = shapeTypes[key];
        if (!checker) {
          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
            '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
            '\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')
          );
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }

    return createChainableTypeChecker(validate);
  }

  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }

        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            // Iterator will provide entry [k,v] tuples rather than values.
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }

        return true;
      default:
        return false;
    }
  }

  function isSymbol(propType, propValue) {
    // Native Symbol.
    if (propType === 'symbol') {
      return true;
    }

    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }

    // Fallback for non-spec compliant Symbols which are polyfilled.
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }

    return false;
  }

  // Equivalent of `typeof` but with special handling for array and regexp.
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      // Old webkits (at least until Android 4.0) return 'function' rather than
      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
      // passes PropTypes.object.
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }

  // This handles more types than `getPropType`. Only used for error messages.
  // See `createPrimitiveTypeChecker`.
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }

  // Returns a string that is postfixed to a warning about an invalid type.
  // For example, "undefined" or "of type array"
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }

  // Returns class name of the object, if any.
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }

  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

function emptyFunction() {}

var factoryWithThrowingShims = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret_1) {
      // It is still safe when called from React.
      return;
    }
    var err = new Error(
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
    err.name = 'Invariant Violation';
    throw err;
  }  shim.isRequired = shim;
  function getShim() {
    return shim;
  }  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim,
    exact: getShim
  };

  ReactPropTypes.checkPropTypes = emptyFunction;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var propTypes = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

if (process.env.NODE_ENV !== 'production') {
  var REACT_ELEMENT_TYPE = (typeof Symbol === 'function' &&
    Symbol.for &&
    Symbol.for('react.element')) ||
    0xeac7;

  var isValidElement = function(object) {
    return typeof object === 'object' &&
      object !== null &&
      object.$$typeof === REACT_ELEMENT_TYPE;
  };

  // By explicitly using `prop-types` you are opting into new development behavior.
  // http://fb.me/prop-types-in-prod
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(isValidElement, throwOnDirectAccess);
} else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = factoryWithThrowingShims();
}
});

var slicedToArray = function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
}();

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var _templateObject = taggedTemplateLiteral(['\n  display: block;\n  position: fixed;\n  z-index: 1050;\n  top: 0;\n  left: 50%;\n  overflow: hidden;\n  width: 50%;\n  height: 100vh;\n  pointer-events: none;\n\n  &::before {\n    content: \'\';\n    position: absolute;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100%;\n    transform: scale3d(0, 1, 1);\n    transform-origin: 0 50%;\n    transition: transform 0.3s;\n    transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);\n  }\n\n  .search {\n    position: relative;\n    padding: 2.5rem 1.5rem 0;\n    background: transparent;\n\n    button {\n      position: absolute;\n      top: 2rem;\n      ', '\n      font-size: 2.5rem;\n      opacity: 0;\n      transition: opacity 0.5s;\n    }\n\n    .form {\n      width: 85%;\n      transform: translate3d(-150%, 0, 0);\n      transition: transform 0.3s;\n    }\n\n    input {\n      font-size: 2.5rem;\n      width: 100%;\n    }\n\n    span {\n      font-size: 85%;\n    }\n  }\n\n  &.show {\n    pointer-events: auto;\n\n    &::before {\n      transform: scale3d(1, 1, 1);\n    }\n\n    .search {\n      .form {\n        transform: translate3d(0, 0, 0);\n        transition-delay: 0.15s;\n        transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);\n      }\n\n      button {\n        opacity: 1;\n        z-index: 100;\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    span {\n      width: 90%;\n    }\n\n    input {\n      font-size: 2rem;\n      width: 90%;\n    }\n  }\n'], ['\n  display: block;\n  position: fixed;\n  z-index: 1050;\n  top: 0;\n  left: 50%;\n  overflow: hidden;\n  width: 50%;\n  height: 100vh;\n  pointer-events: none;\n\n  &::before {\n    content: \'\';\n    position: absolute;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100%;\n    transform: scale3d(0, 1, 1);\n    transform-origin: 0 50%;\n    transition: transform 0.3s;\n    transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);\n  }\n\n  .search {\n    position: relative;\n    padding: 2.5rem 1.5rem 0;\n    background: transparent;\n\n    button {\n      position: absolute;\n      top: 2rem;\n      ', '\n      font-size: 2.5rem;\n      opacity: 0;\n      transition: opacity 0.5s;\n    }\n\n    .form {\n      width: 85%;\n      transform: translate3d(-150%, 0, 0);\n      transition: transform 0.3s;\n    }\n\n    input {\n      font-size: 2.5rem;\n      width: 100%;\n    }\n\n    span {\n      font-size: 85%;\n    }\n  }\n\n  &.show {\n    pointer-events: auto;\n\n    &::before {\n      transform: scale3d(1, 1, 1);\n    }\n\n    .search {\n      .form {\n        transform: translate3d(0, 0, 0);\n        transition-delay: 0.15s;\n        transition-timing-function: cubic-bezier(0.86, 0, 0.07, 1);\n      }\n\n      button {\n        opacity: 1;\n        z-index: 100;\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    span {\n      width: 90%;\n    }\n\n    input {\n      font-size: 2rem;\n      width: 90%;\n    }\n  }\n']);

var columnCurtain = styled.css(_templateObject, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
});

var _templateObject$1 = taggedTemplateLiteral(['\n  .search {\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 100%;\n    overflow: hidden;\n    height: 100vh;\n    width: 100%;\n    padding: 3rem;\n    pointer-events: none;\n    transition: transform 0.3s;\n    transition-delay: 0.4s;\n    transition-timing-function: ease-out;\n\n    &::after {\n      content: \'\';\n      position: absolute;\n      top: 0;\n      left: 0;\n      width: 100%;\n      height: 100%;\n      transition: transform 0.3s;\n      transition-timing-function: ease-out;\n    }\n\n    button {\n      font-size: 2.5rem;\n      position: absolute;\n      top: 3rem;\n      ', '\n      transition: opacity 0.1s;\n      transition-delay: 0.3s;\n    }\n\n    .form {\n      width: 50%;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n\n    input {\n      width: 100%;\n      font-size: 6vw;\n    }\n  }\n\n  &.show {\n    .search {\n      width: 100%;\n      pointer-events: auto;\n      transform: translate3d(-100%, 0, 0);\n      transition-delay: 0s;\n\n      &::after {\n        transform: translate3d(100%, 0, 0);\n        transition-delay: 0.4s;\n      }\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n    }\n  }\n\n  @media screen and (max-width: 40em) {\n    span {\n      width: 90%;\n    }\n\n    input {\n      font-size: 2em;\n      width: 90%;\n    }\n  }\n'], ['\n  .search {\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 100%;\n    overflow: hidden;\n    height: 100vh;\n    width: 100%;\n    padding: 3rem;\n    pointer-events: none;\n    transition: transform 0.3s;\n    transition-delay: 0.4s;\n    transition-timing-function: ease-out;\n\n    &::after {\n      content: \'\';\n      position: absolute;\n      top: 0;\n      left: 0;\n      width: 100%;\n      height: 100%;\n      transition: transform 0.3s;\n      transition-timing-function: ease-out;\n    }\n\n    button {\n      font-size: 2.5rem;\n      position: absolute;\n      top: 3rem;\n      ', '\n      transition: opacity 0.1s;\n      transition-delay: 0.3s;\n    }\n\n    .form {\n      width: 50%;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n\n    input {\n      width: 100%;\n      font-size: 6vw;\n    }\n  }\n\n  &.show {\n    .search {\n      width: 100%;\n      pointer-events: auto;\n      transform: translate3d(-100%, 0, 0);\n      transition-delay: 0s;\n\n      &::after {\n        transform: translate3d(100%, 0, 0);\n        transition-delay: 0.4s;\n      }\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n    }\n  }\n\n  @media screen and (max-width: 40em) {\n    span {\n      width: 90%;\n    }\n\n    input {\n      font-size: 2em;\n      width: 90%;\n    }\n  }\n']);

var curtain = styled.css(_templateObject$1, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
});

var _templateObject$2 = taggedTemplateLiteral(['\n  0% {\n    opacity: 1;\n    transform: scale3d(1, 0, 1);\n  }\n  50% {\n    transform: scale3d(1, 1, 1);\n    transform-origin: 50% 0;\n    transition-timing-function: ease-out;\n  }\n  50.1% {\n    transform-origin: 50% 100%;\n    transition-timing-function: ease-out;\n  }\n  100% {\n    opacity: 1;\n    transform: scale3d(1, 0, 1);\n    transform-origin: 50% 100%;\n    transition-timing-function: ease-out;\n  }   \n'], ['\n  0% {\n    opacity: 1;\n    transform: scale3d(1, 0, 1);\n  }\n  50% {\n    transform: scale3d(1, 1, 1);\n    transform-origin: 50% 0;\n    transition-timing-function: ease-out;\n  }\n  50.1% {\n    transform-origin: 50% 100%;\n    transition-timing-function: ease-out;\n  }\n  100% {\n    opacity: 1;\n    transform: scale3d(1, 0, 1);\n    transform-origin: 50% 100%;\n    transition-timing-function: ease-out;\n  }   \n']),
    _templateObject2 = taggedTemplateLiteral(['\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    z-index: 1050;\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100vh;\n    background: 0 0;\n    pointer-events: none;\n\n    &::before {\n      content: \'\';\n      position: absolute;\n      top: 0;\n      right: 0;\n      width: 100%;\n      height: 100%;\n      opacity: 0;\n      transition: opacity 0.4s;\n    }\n\n    button {\n      font-size: 2.5rem;\n      position: absolute;\n      top: 3rem;\n      ', '\n      display: block;\n      opacity: 0;\n      transition: opacity 0.4s;\n    }\n\n    .form {\n      position: relative;\n      margin: 5rem 0 2rem;\n    }\n\n    input {\n      font-size: 6vw;\n      width: 60%;\n      padding: 0.25rem;\n      text-align: center;\n      opacity: 0;\n      transition: opacity 0.4s;\n    }\n\n    span {\n      position: relative;\n      z-index: 9;\n      display: block;\n      width: 60%;\n      padding: 0.85rem 0;\n      opacity: 0;\n      transform: translate3d(0, -50px, 0);\n      transition: opacity 0.4s, transform 0.4s;\n    }\n\n    .form-content {\n      position: relative;\n      z-index: 10;\n      overflow: hidden;\n      transform: translate3d(0, -50px, 0);\n      transition: transform 0.4s;\n\n      &::after {\n        content: \'\';\n        position: absolute;\n        top: 0;\n        left: 20%;\n        width: 60%;\n        height: 105%;\n        opacity: 0;\n        transform-origin: 50% 0;\n      }\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n\n      &::before {\n        opacity: 1;\n      }\n\n      button {\n        opacity: 1;\n      }\n\n      .form-content {\n        transform: translate3d(0, 0, 0);\n        transition: none;\n\n        &::after {\n          animation: ', ' 0.8s cubic-bezier(0.4, 0, 0.2, 1) forwards;\n        }\n      }\n\n      input {\n        opacity: 1;\n        transition: opacity 0s 0.4s;\n      }\n\n      span {\n        opacity: 1;\n        transform: translate3d(0, 0, 0);\n        transition-delay: 0.4s;\n        transition-timing-function: ease-out;\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    .form {\n      margin: 2rem 0;\n    }\n\n    input {\n      width: 100%;\n      left: 0;\n    }\n  }\n'], ['\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    z-index: 1050;\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100vh;\n    background: 0 0;\n    pointer-events: none;\n\n    &::before {\n      content: \'\';\n      position: absolute;\n      top: 0;\n      right: 0;\n      width: 100%;\n      height: 100%;\n      opacity: 0;\n      transition: opacity 0.4s;\n    }\n\n    button {\n      font-size: 2.5rem;\n      position: absolute;\n      top: 3rem;\n      ', '\n      display: block;\n      opacity: 0;\n      transition: opacity 0.4s;\n    }\n\n    .form {\n      position: relative;\n      margin: 5rem 0 2rem;\n    }\n\n    input {\n      font-size: 6vw;\n      width: 60%;\n      padding: 0.25rem;\n      text-align: center;\n      opacity: 0;\n      transition: opacity 0.4s;\n    }\n\n    span {\n      position: relative;\n      z-index: 9;\n      display: block;\n      width: 60%;\n      padding: 0.85rem 0;\n      opacity: 0;\n      transform: translate3d(0, -50px, 0);\n      transition: opacity 0.4s, transform 0.4s;\n    }\n\n    .form-content {\n      position: relative;\n      z-index: 10;\n      overflow: hidden;\n      transform: translate3d(0, -50px, 0);\n      transition: transform 0.4s;\n\n      &::after {\n        content: \'\';\n        position: absolute;\n        top: 0;\n        left: 20%;\n        width: 60%;\n        height: 105%;\n        opacity: 0;\n        transform-origin: 50% 0;\n      }\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n\n      &::before {\n        opacity: 1;\n      }\n\n      button {\n        opacity: 1;\n      }\n\n      .form-content {\n        transform: translate3d(0, 0, 0);\n        transition: none;\n\n        &::after {\n          animation: ', ' 0.8s cubic-bezier(0.4, 0, 0.2, 1) forwards;\n        }\n      }\n\n      input {\n        opacity: 1;\n        transition: opacity 0s 0.4s;\n      }\n\n      span {\n        opacity: 1;\n        transform: translate3d(0, 0, 0);\n        transition-delay: 0.4s;\n        transition-timing-function: ease-out;\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    .form {\n      margin: 2rem 0;\n    }\n\n    input {\n      width: 100%;\n      left: 0;\n    }\n  }\n']);

var scaleUpDown = styled.keyframes(_templateObject$2);

var modalDrop = styled.css(_templateObject2, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
}, scaleUpDown);

var _templateObject$3 = taggedTemplateLiteral(['\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100vh;\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity 0.5s;\n\n    button {\n      position: absolute;\n      top: 3rem;\n      ', '\n      font-size: 2.5rem;\n      opacity: 0;\n      transition: opacity 0.5s;\n    }\n\n    .form {\n      margin: 5rem 0;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n\n    input {\n      font-size: 10vw;\n      width: 75%;\n      transform: scale3d(0, 1, 1);\n      transform-origin: 0 50%;\n      transition: transform 0.3s;\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n      opacity: 1;\n\n      button {\n        opacity: 1;\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      input {\n        transform: scale3d(1, 1, 1);\n        transition-duration: 0.5s;\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    span {\n      text-align: left;\n    }\n  }\n'], ['\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100vh;\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity 0.5s;\n\n    button {\n      position: absolute;\n      top: 3rem;\n      ', '\n      font-size: 2.5rem;\n      opacity: 0;\n      transition: opacity 0.5s;\n    }\n\n    .form {\n      margin: 5rem 0;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n\n    input {\n      font-size: 10vw;\n      width: 75%;\n      transform: scale3d(0, 1, 1);\n      transform-origin: 0 50%;\n      transition: transform 0.3s;\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n      opacity: 1;\n\n      button {\n        opacity: 1;\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      input {\n        transform: scale3d(1, 1, 1);\n        transition-duration: 0.5s;\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    span {\n      text-align: left;\n    }\n  }\n']);

var modalMove = styled.css(_templateObject$3, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
});

var _templateObject$4 = taggedTemplateLiteral(['\n  .search {\n    text-align: center;\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 0;\n    overflow: hidden;\n    width: 100%;\n    height: 100vh;\n    background: none;\n    pointer-events: none;\n\n    &::before {\n      content: \'\';\n      position: absolute;\n      top: 0;\n      left: 0;\n      width: 100%;\n      height: 100%;\n      pointer-events: none;\n      opacity: 0;\n      transition: opacity 0.6s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    button {\n      font-size: 2.5rem;\n      position: absolute;\n      top: 3rem;\n      ', '\n      display: block;\n      z-index: 100;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.6s, transform 0.6s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    .form-wrapper {\n      position: absolute;\n      display: flex;\n      justify-content: center;\n      align-items: center;\n      width: 100%;\n      height: 50%;\n      transition: transform 0.6s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n      transform: translate3d(0, -100%, 0);\n    }\n\n    .form {\n      width: 75%;\n      margin: 0 auto;\n    }\n\n    input {\n      font-size: 7vw;\n      width: 100%;\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n\n      &::before {\n        opacity: 1;\n      }\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form-wrapper {\n        transform: translate3d(0, 0, 0);\n      }\n    }\n  }\n'], ['\n  .search {\n    text-align: center;\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 0;\n    overflow: hidden;\n    width: 100%;\n    height: 100vh;\n    background: none;\n    pointer-events: none;\n\n    &::before {\n      content: \'\';\n      position: absolute;\n      top: 0;\n      left: 0;\n      width: 100%;\n      height: 100%;\n      pointer-events: none;\n      opacity: 0;\n      transition: opacity 0.6s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    button {\n      font-size: 2.5rem;\n      position: absolute;\n      top: 3rem;\n      ', '\n      display: block;\n      z-index: 100;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.6s, transform 0.6s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    .form-wrapper {\n      position: absolute;\n      display: flex;\n      justify-content: center;\n      align-items: center;\n      width: 100%;\n      height: 50%;\n      transition: transform 0.6s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n      transform: translate3d(0, -100%, 0);\n    }\n\n    .form {\n      width: 75%;\n      margin: 0 auto;\n    }\n\n    input {\n      font-size: 7vw;\n      width: 100%;\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n\n      &::before {\n        opacity: 1;\n      }\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form-wrapper {\n        transform: translate3d(0, 0, 0);\n      }\n    }\n  }\n']);

var modalHalf = styled.css(_templateObject$4, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
});

var _templateObject$5 = taggedTemplateLiteral(['\n  display: block;\n\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100vh;\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity 0.5s;\n\n    &::before,\n    &::after {\n      content: \'\';\n      position: absolute;\n      width: calc(100% + 15px);\n      height: calc(100% + 15px);\n      pointer-events: none;\n    }\n\n    &::before {\n      top: 0;\n      left: 0;\n      border-right-width: 0;\n      border-bottom-width: 0;\n      transform: translate3d(-15px, -15px, 0);\n    }\n\n    &::after {\n      right: 0;\n      bottom: 0;\n      border-top-width: 0;\n      border-left-width: 0;\n      transform: translate3d(15px, 15px, 0);\n    }\n\n    button {\n      position: absolute;\n      top: 3rem;\n      ', '\n      font-size: 2.5rem;\n    }\n\n    input {\n      font-size: 10vw;\n      width: 75%;\n    }\n\n    button {\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n\n    .form {\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n      opacity: 1;\n\n      &::before,\n      &::after {\n        transform: translate3d(0, 0, 0);\n        transition: transform 0.5s;\n      }\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    .form {\n      margin: 5rem 0 1rem;\n    }\n\n    span {\n      text-align: left;\n    }\n  }\n'], ['\n  display: block;\n\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    position: fixed;\n    z-index: 1050;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100vh;\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity 0.5s;\n\n    &::before,\n    &::after {\n      content: \'\';\n      position: absolute;\n      width: calc(100% + 15px);\n      height: calc(100% + 15px);\n      pointer-events: none;\n    }\n\n    &::before {\n      top: 0;\n      left: 0;\n      border-right-width: 0;\n      border-bottom-width: 0;\n      transform: translate3d(-15px, -15px, 0);\n    }\n\n    &::after {\n      right: 0;\n      bottom: 0;\n      border-top-width: 0;\n      border-left-width: 0;\n      transform: translate3d(15px, 15px, 0);\n    }\n\n    button {\n      position: absolute;\n      top: 3rem;\n      ', '\n      font-size: 2.5rem;\n    }\n\n    input {\n      font-size: 10vw;\n      width: 75%;\n    }\n\n    button {\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n\n    .form {\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n    }\n  }\n\n  &.show {\n    .search {\n      pointer-events: auto;\n      opacity: 1;\n\n      &::before,\n      &::after {\n        transform: translate3d(0, 0, 0);\n        transition: transform 0.5s;\n      }\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n    }\n  }\n\n  @media screen and (max-width: 40rem) {\n    .form {\n      margin: 5rem 0 1rem;\n    }\n\n    span {\n      text-align: left;\n    }\n  }\n']);

var modalZoomin = styled.css(_templateObject$5, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
});

var _templateObject$6 = taggedTemplateLiteral(['\n  position: absolute;\n  display: block;\n  width: 100vw;\n  height: 100vh;\n  pointer-events: none;\n  opacity: 0;\n  transition-property: opacity;\n  transition-delay: 0.4s;\n\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    z-index: 1050;\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 50vh;\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity 0.5s;\n    transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n\n    button {\n      position: absolute;\n      top: 3rem;\n      ', '\n      font-size: 2.5rem;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    .form {\n      margin: 5rem 0;\n      opacity: 0;\n      transform: scale3d(0.7, 0.7, 1);\n      transition: opacity 0.5s, transform 0.5s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    input {\n      font-size: 7vw;\n      width: 75%;\n    }\n  }\n\n  &.show {\n    opacity: 1;\n    transition-delay: 0s;\n\n    .search {\n      pointer-events: auto;\n      opacity: 1;\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n    }\n  }\n'], ['\n  position: absolute;\n  display: block;\n  width: 100vw;\n  height: 100vh;\n  pointer-events: none;\n  opacity: 0;\n  transition-property: opacity;\n  transition-delay: 0.4s;\n\n  .search {\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: center;\n    text-align: center;\n    z-index: 1050;\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 50vh;\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity 0.5s;\n    transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n\n    button {\n      position: absolute;\n      top: 3rem;\n      ', '\n      font-size: 2.5rem;\n      opacity: 0;\n      transform: scale3d(0.8, 0.8, 1);\n      transition: opacity 0.5s, transform 0.5s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    .form {\n      margin: 5rem 0;\n      opacity: 0;\n      transform: scale3d(0.7, 0.7, 1);\n      transition: opacity 0.5s, transform 0.5s;\n      transition-timing-function: cubic-bezier(0.2, 1, 0.3, 1);\n    }\n\n    input {\n      font-size: 7vw;\n      width: 75%;\n    }\n  }\n\n  &.show {\n    opacity: 1;\n    transition-delay: 0s;\n\n    .search {\n      pointer-events: auto;\n      opacity: 1;\n\n      button {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n\n      .form {\n        opacity: 1;\n        transform: scale3d(1, 1, 1);\n      }\n    }\n  }\n']);

var rotateLayout = styled.css(_templateObject$6, function (_ref) {
  var theme = _ref.theme;
  return theme.dir === 'rtl' ? 'left: 3rem;' : 'right: 3rem;';
});

var _templateObject$7 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2$1 = taggedTemplateLiteral(['\n    button {\n      path {\n        fill: ', ';\n      }\n      margin: 0 auto;\n      padding: 0;\n      cursor: pointer;\n      border: none;\n      background: none;\n\n      &:focus {\n        box-shadow: none;\n        outline: none;\n      }\n    }\n  '], ['\n    button {\n      path {\n        fill: ', ';\n      }\n      margin: 0 auto;\n      padding: 0;\n      cursor: pointer;\n      border: none;\n      background: none;\n\n      &:focus {\n        box-shadow: none;\n        outline: none;\n      }\n    }\n  ']),
    _templateObject3 = taggedTemplateLiteral(['\n  \n    .search {\n      background: ', ';\n\n      button {\n        g {\n          fill: ', ';\n        }\n        margin: 0;\n        padding: 0;\n        cursor: pointer;\n        border: none;\n        background: none;\n\n        &:focus {\n          box-shadow: none;\n          outline: none;\n        }\n      }\n\n      span {\n        color: ', ';\n        font-size: 90%;\n        font-weight: bold;\n        display: block;\n        width: 75%;\n        margin: 0 auto;\n        padding: 0.85rem 0;\n        text-align: right;\n      }\n\n      input {\n        color: ', ';\n        border-bottom: 4px solid ', ';\n        border-top: 0;\n        border-right: 0;\n        border-left: 0;\n        background: transparent;\n        border-radius: 0;\n        line-height: 1;\n        display: inline-block;\n        box-sizing: border-box;\n        padding: 0.05rem 0;\n        -webkit-appearance: none;\n\n        &::placeholder {\n          color: ', ';\n          opacity: 0.3;\n        }\n        &:focus {\n          outline: none;\n        }\n\n\n        &::-ms-clear {\n          display: none;\n        }\n      }\n    }\n\n    &.rotate-layout {\n      ', '\n      background: ', ';\n    }\n\n    &.modal-zoomin {\n      ', '\n      .search::before,\n      .search::after {\n        border: 1.5rem solid ', ';\n      }\n    }\n\n    &.modal-half {\n      ', '\n      .form-wrapper {\n        background: ', ';\n      }\n      .search::before {\n        background: ', ';\n      }\n    }\n    &.modal-move {\n      ', '\n    }\n\n    &.modal-drop {\n      .form-content::after {\n        background: ', ';\n      }\n      .search::before {\n        background: ', ';\n      }\n      ', '\n    }\n\n    &.curtain {\n      ', '\n      .search::after {\n        background: ', ';\n      }\n      .search {\n        background: ', ';\n      }\n    }\n\n    &.column-curtain {\n      ', '\n      &::before {\n        background: ', ';\n      }\n      &::after {\n        background: transparent;\n      }\n      &.show::after {\n        background: ', ';\n      }\n    }\n  '], ['\n  \n    .search {\n      background: ', ';\n\n      button {\n        g {\n          fill: ', ';\n        }\n        margin: 0;\n        padding: 0;\n        cursor: pointer;\n        border: none;\n        background: none;\n\n        &:focus {\n          box-shadow: none;\n          outline: none;\n        }\n      }\n\n      span {\n        color: ', ';\n        font-size: 90%;\n        font-weight: bold;\n        display: block;\n        width: 75%;\n        margin: 0 auto;\n        padding: 0.85rem 0;\n        text-align: right;\n      }\n\n      input {\n        color: ', ';\n        border-bottom: 4px solid ', ';\n        border-top: 0;\n        border-right: 0;\n        border-left: 0;\n        background: transparent;\n        border-radius: 0;\n        line-height: 1;\n        display: inline-block;\n        box-sizing: border-box;\n        padding: 0.05rem 0;\n        -webkit-appearance: none;\n\n        &::placeholder {\n          color: ', ';\n          opacity: 0.3;\n        }\n        &:focus {\n          outline: none;\n        }\n\n\n        &::-ms-clear {\n          display: none;\n        }\n      }\n    }\n\n    &.rotate-layout {\n      ', '\n      background: ', ';\n    }\n\n    &.modal-zoomin {\n      ', '\n      .search::before,\n      .search::after {\n        border: 1.5rem solid ', ';\n      }\n    }\n\n    &.modal-half {\n      ', '\n      .form-wrapper {\n        background: ', ';\n      }\n      .search::before {\n        background: ', ';\n      }\n    }\n    &.modal-move {\n      ', '\n    }\n\n    &.modal-drop {\n      .form-content::after {\n        background: ', ';\n      }\n      .search::before {\n        background: ', ';\n      }\n      ', '\n    }\n\n    &.curtain {\n      ', '\n      .search::after {\n        background: ', ';\n      }\n      .search {\n        background: ', ';\n      }\n    }\n\n    &.column-curtain {\n      ', '\n      &::before {\n        background: ', ';\n      }\n      &::after {\n        background: transparent;\n      }\n      &.show::after {\n        background: ', ';\n      }\n    }\n  ']);

var SearchStyle = styled__default.div(_templateObject$7, function (_ref) {
  var theme = _ref.theme;
  return styled.css(_templateObject2$1, theme.searchBtnOpenFg);
});

var SearchFieldStyle = styled__default.div(_templateObject$7, function (_ref2) {
  var theme = _ref2.theme;
  return styled.css(_templateObject3, theme.searchBg, theme.searchBtnCloseFg, theme.searchInfo, theme.searchText, theme.searchDash, theme.searchPlaceholder, rotateLayout, theme.searchBg, modalZoomin, theme.searchBgSecondary, modalHalf, theme.searchBg, theme.searchBgSecondary, modalMove, theme.searchDash, theme.searchBg, modalDrop, curtain, theme.searchBg, theme.searchBg, columnCurtain, theme.searchBg, theme.searchBgSecondary);
});

var _ref =
/*#__PURE__*/
React__default.createElement("path", {
  fill: "#99ABB4",
  fillRule: "evenodd",
  stroke: "#99ABB4",
  d: "M8 6.982L2.428 2l-.363.324 5.208 4.658L2 11.676l.363.324z"
});

var _ref$1 =
/*#__PURE__*/
React__default.createElement("path", {
  fill: "#99ABB4",
  fillRule: "evenodd",
  stroke: "#99ABB4",
  d: "M2 7.018L7.572 12l.363-.324-5.208-4.658L8 2.324 7.637 2z"
});

var _ref$2 =
/*#__PURE__*/
React__default.createElement("path", {
  fill: "#99ABB4",
  fillRule: "evenodd",
  stroke: "#99ABB4",
  d: "M6.982 2L2 7.572l.324.363 4.658-5.208L11.676 8 12 7.637z"
});

var _ref$3 =
/*#__PURE__*/
React__default.createElement("path", {
  fill: "#99ABB4",
  fillRule: "evenodd",
  stroke: "#99ABB4",
  d: "M7.018 8L12 2.428l-.324-.363-4.658 5.208L2.324 2 2 2.363z"
});

function _extends$5() {
  _extends$5 = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }return target;
  };return _extends$5.apply(this, arguments);
}

var _ref$4 =
/*#__PURE__*/
React__default.createElement("path", {
  fill: "#FFF",
  fillRule: "evenodd",
  d: "M12.979 13.651c-.145.22-.508.22-.653 0a.494.494 0 0 1 0-.734 5.058 5.058 0 0 0 1.305-1.761 5.32 5.32 0 0 0 .435-2.128c0-.955-.217-1.835-.652-2.57a4.747 4.747 0 0 0-1.885-1.908c-.218-.146-.29-.44-.145-.733.145-.22.435-.294.725-.147.87.587 1.667 1.32 2.175 2.275.508.954.798 1.982.798 3.083 0 .88-.218 1.761-.508 2.568a5.431 5.431 0 0 1-1.595 2.055zM8.919 0c2.465 0 4.64 1.028 6.308 2.642a9.1 9.1 0 0 1 2.61 6.386c0 2.201-.87 4.256-2.175 5.871L16.822 16l.217-.294c.363-.293.725-.44 1.16-.44.363 0 .798.147 1.088.44l4.278 4.257c.29.367.435.734.435 1.175 0 .367-.145.807-.435 1.1L22.26 23.56c-.29.293-.653.44-1.088.44-.435 0-.797-.147-1.087-.44l-4.278-4.257c-.29-.367-.435-.734-.435-1.175 0-.367.145-.807.435-1.1l.29-.294-1.16-1.101a8.76 8.76 0 0 1-6.019 2.422 8.88 8.88 0 0 1-6.308-2.642C1.015 13.725 0 11.523 0 9.028a9.1 9.1 0 0 1 2.61-6.386A8.88 8.88 0 0 1 8.918 0zm5.583 3.376c-1.45-1.468-3.408-2.348-5.584-2.348-2.175 0-4.133.88-5.583 2.348a7.98 7.98 0 0 0-2.32 5.652 7.98 7.98 0 0 0 2.32 5.65c1.45 1.395 3.408 2.35 5.583 2.35 2.176 0 4.133-.955 5.584-2.35l.072-.146h.073c1.305-1.468 2.175-3.376 2.175-5.504 0-2.202-.943-4.184-2.32-5.652z"
});

var SvgComponent$4 = function SvgComponent(props) {
  return React__default.createElement("svg", _extends$5({
    width: 24,
    height: 24
  }, props), _ref$4);
};

function _extends$6() {
  _extends$6 = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }return target;
  };return _extends$6.apply(this, arguments);
}

var _ref$5 =
/*#__PURE__*/
React__default.createElement("g", {
  fillRule: "evenodd"
}, React__default.createElement("path", {
  d: "M12.78 11.95l5.039-5.058a.554.554 0 0 0 0-.78.548.548 0 0 0-.778 0l-5.038 5.057L6.965 6.11a.548.548 0 0 0-.778 0 .554.554 0 0 0 0 .781l5.038 5.057-5.048 5.068a.554.554 0 0 0 0 .78.548.548 0 0 0 .778 0L12 12.73l5.048 5.068a.548.548 0 0 0 .92-.248.553.553 0 0 0-.142-.533L12.78 11.95z"
}), React__default.createElement("path", {
  fillRule: "nonzero",
  d: "M20.42 3.502A11.874 11.874 0 0 0 5.384 2.016C.66 5.184-1.176 11.26.998 16.53c2.175 5.269 7.754 8.262 13.326 7.149 5.572-1.113 9.585-6.022 9.584-11.725a11.899 11.899 0 0 0-3.488-8.452zm-.778 16.125a10.778 10.778 0 0 1-13.648 1.348C1.707 18.098.04 12.582 2.014 7.8 3.988 3.018 9.052.301 14.11 1.311c5.057 1.01 8.7 5.467 8.7 10.643a10.8 10.8 0 0 1-3.167 7.673z"
}));

var SvgComponent$5 = function SvgComponent(props) {
  return React__default.createElement("svg", _extends$6({
    width: 24,
    height: 24
  }, props), _ref$5);
};

function CloseCircled$1() {
  return React__default.createElement(SvgComponent$5, null);
}
function SearchIcon() {
  return React__default.createElement(SvgComponent$4, null);
}

var _templateObject$8 = taggedTemplateLiteral(['\n  position: absolute;\n  pointer-events: auto;\n  box-sizing: border-box;\n  z-index: 1000;\n  display: flex;\n  max-width: 100%;\n  max-height: 100%;\n'], ['\n  position: absolute;\n  pointer-events: auto;\n  box-sizing: border-box;\n  z-index: 1000;\n  display: flex;\n  max-width: 100%;\n  max-height: 100%;\n']);

var OverlayStyle = styled__default.div(_templateObject$8);

function Overlay(props) {
  var _useState = React.useState(),
      _useState2 = slicedToArray(_useState, 2),
      parent = _useState2[0],
      setParent = _useState2[1];

  React.useEffect(function () {
    var overlayParent = document.getElementById('overlay-container');
    setParent(overlayParent);
  }, []);
  return parent !== undefined && ReactDOM.createPortal(React__default.createElement(
    OverlayStyle,
    props,
    props.children
  ), parent);
}

Overlay.propTypes = {
  children: propTypes.node
};

var layoutContext = React__default.createContext({
  addClass: function addClass() {},
  removeClass: function removeClass() {},
  addEventListener: function addEventListener() {},
  removeEventListener: function removeEventListener() {},
  dir: 'ltr'
});

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

function Search$1(props) {
  var _useState = React.useState(''),
      _useState2 = slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = React.useState(),
      _useState4 = slicedToArray(_useState3, 2),
      show = _useState4[0],
      setShow = _useState4[1];

  var inputRef = React.useRef();
  var layout = React.useContext(layoutContext);

  React.useEffect(function () {
    if (show === 'show') {
      inputRef.current.focus();
    } else if (show === undefined) {
      layout.removeClass([props.type]);
    }
  }, [show]);

  var handleOpen = function handleOpen() {
    setShow('');
    layout.addClass([props.type, 'with-search']);
    setTimeout(function () {
      setShow('show');
    }, 50);
  };

  var handleClose = function handleClose() {
    layout.removeClass(['with-search']);
    setShow('');
    setTimeout(function () {
      setShow(undefined);
    }, 200);
  };

  var onChangeHandle = function onChangeHandle(e) {
    typeof props.onChange === 'function' && props.onChange(e.target.value);
    setValue(e.target.value);
  };

  return React__default.createElement(
    SearchStyle,
    { className: props.className },
    React__default.createElement(
      'button',
      { onClick: handleOpen },
      React__default.createElement(SearchIcon, null)
    ),
    show !== undefined && React__default.createElement(
      Overlay,
      null,
      React__default.createElement(
        SearchFieldStyle,
        { className: props.type + ' ' + show },
        React__default.createElement(
          'div',
          {
            className: 'search',
            onKeyUp: function onKeyUp(e) {
              e.preventDefault();
              e.key === 'Escape' && handleClose();
            }
          },
          React__default.createElement(
            'button',
            { onClick: handleClose },
            React__default.createElement(CloseCircled$1, null)
          ),
          React__default.createElement(
            'div',
            { className: 'form-wrapper' },
            React__default.createElement(
              'div',
              { className: 'form' },
              React__default.createElement(
                'div',
                { className: 'form-content' },
                React__default.createElement('input', {
                  ref: inputRef,
                  onKeyUp: function onKeyUp(e) {
                    e.preventDefault();
                    if (e.key === 'Enter') {
                      handleClose();
                      props.submit(value);
                    }
                  },
                  onChange: onChangeHandle,
                  placeholder: props.placeholder,
                  className: 'search-input',
                  autoComplete: 'off',
                  tabIndex: '-1',
                  value: value
                })
              ),
              React__default.createElement(
                'span',
                { className: 'info' },
                props.hint
              )
            )
          )
        )
      )
    )
  );
}
Search$1.propTypes = {
  hint: propTypes.string,
  placeholder: propTypes.string,
  submit: propTypes.func.isRequired,
  onChange: propTypes.func,
  type: propTypes.oneOf(['rotate-layout', 'modal-zoomin', 'modal-move', 'modal-drop', 'modal-half', 'curtain', 'column-curtain']).isRequired
};

module.exports = Search$1;
