'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var ReactDOM = _interopDefault(require('react-dom'));
var React = require('react');
var React__default = _interopDefault(React);
var styled = require('styled-components');
var styled__default = _interopDefault(styled);

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
/* eslint-disable no-unused-vars */
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;

function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}

	return Object(val);
}

function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}

		// Detect buggy property enumeration order in older V8 versions.

		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}

		return true;
	} catch (err) {
		// We don't expect any of the above to throw, but better to be safe.
		return false;
	}
}

var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;

	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);

		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}

		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}

	return to;
};

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

var ReactPropTypesSecret_1 = ReactPropTypesSecret;

var printWarning = function() {};

if (process.env.NODE_ENV !== 'production') {
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};

  printWarning = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

/**
 * Assert that the values match with the type specs.
 * Error messages are memorized and will only be shown once.
 *
 * @param {object} typeSpecs Map of name to a ReactPropType
 * @param {object} values Runtime values that need to be type-checked
 * @param {string} location e.g. "prop", "context", "child context"
 * @param {string} componentName Name of the component for error messages.
 * @param {?Function} getStack Returns the component stack.
 * @private
 */
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  if (process.env.NODE_ENV !== 'production') {
    for (var typeSpecName in typeSpecs) {
      if (typeSpecs.hasOwnProperty(typeSpecName)) {
        var error;
        // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.
        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error(
              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'
            );
            err.name = 'Invariant Violation';
            throw err;
          }
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        if (error && !(error instanceof Error)) {
          printWarning(
            (componentName || 'React class') + ': type specification of ' +
            location + ' `' + typeSpecName + '` is invalid; the type checker ' +
            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
            'You may have forgotten to pass an argument to the type checker ' +
            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
            'shape all require an argument).'
          );

        }
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error.message] = true;

          var stack = getStack ? getStack() : '';

          printWarning(
            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
          );
        }
      }
    }
  }
}

var checkPropTypes_1 = checkPropTypes;

var printWarning$1 = function() {};

if (process.env.NODE_ENV !== 'production') {
  printWarning$1 = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

function emptyFunctionThatReturnsNull() {
  return null;
}

var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  /* global Symbol */
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

  /**
   * Returns the iterator method function contained on the iterable object.
   *
   * Be sure to invoke the function with the iterable as context:
   *
   *     var iteratorFn = getIteratorFn(myIterable);
   *     if (iteratorFn) {
   *       var iterator = iteratorFn.call(myIterable);
   *       ...
   *     }
   *
   * @param {?object} maybeIterable
   * @return {?function}
   */
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }

  /**
   * Collection of methods that allow declaration and validation of props that are
   * supplied to React components. Example usage:
   *
   *   var Props = require('ReactPropTypes');
   *   var MyArticle = React.createClass({
   *     propTypes: {
   *       // An optional string prop named "description".
   *       description: Props.string,
   *
   *       // A required enum prop named "category".
   *       category: Props.oneOf(['News','Photos']).isRequired,
   *
   *       // A prop named "dialog" that requires an instance of Dialog.
   *       dialog: Props.instanceOf(Dialog).isRequired
   *     },
   *     render: function() { ... }
   *   });
   *
   * A more formal specification of how these methods are used:
   *
   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
   *   decl := ReactPropTypes.{type}(.isRequired)?
   *
   * Each and every declaration produces a function with the same signature. This
   * allows the creation of custom validation functions. For example:
   *
   *  var MyLink = React.createClass({
   *    propTypes: {
   *      // An optional string or URI prop named "href".
   *      href: function(props, propName, componentName) {
   *        var propValue = props[propName];
   *        if (propValue != null && typeof propValue !== 'string' &&
   *            !(propValue instanceof URI)) {
   *          return new Error(
   *            'Expected a string or an URI for ' + propName + ' in ' +
   *            componentName
   *          );
   *        }
   *      }
   *    },
   *    render: function() {...}
   *  });
   *
   * @internal
   */

  var ANONYMOUS = '<<anonymous>>';

  // Important!
  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),

    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker,
    exact: createStrictShapeTypeChecker,
  };

  /**
   * inlined Object.is polyfill to avoid requiring consumers ship their own
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
   */
  /*eslint-disable no-self-compare*/
  function is(x, y) {
    // SameValue algorithm
    if (x === y) {
      // Steps 1-5, 7-10
      // Steps 6.b-6.e: +0 != -0
      return x !== 0 || 1 / x === 1 / y;
    } else {
      // Step 6.a: NaN == NaN
      return x !== x && y !== y;
    }
  }
  /*eslint-enable no-self-compare*/

  /**
   * We use an Error-like object for backward compatibility as people may call
   * PropTypes directly and inspect their output. However, we don't use real
   * Errors anymore. We don't inspect their stack anyway, and creating them
   * is prohibitively expensive if they are created too often, such as what
   * happens in oneOfType() for any type before the one that matched.
   */
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  // Make `instanceof Error` still work for returned errors.
  PropTypeError.prototype = Error.prototype;

  function createChainableTypeChecker(validate) {
    if (process.env.NODE_ENV !== 'production') {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;

      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          // New behavior only for users of `prop-types` package
          var err = new Error(
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
          err.name = 'Invariant Violation';
          throw err;
        } else if (process.env.NODE_ENV !== 'production' && typeof console !== 'undefined') {
          // Old behavior for people using React.PropTypes
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            // Avoid spamming the console because they are often not actionable except for lib authors
            manualPropTypeWarningCount < 3
          ) {
            printWarning$1(
              'You are manually calling a React.PropTypes validation ' +
              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }

    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);

    return chainedCheckType;
  }

  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        // `propValue` being instance of, say, date/regexp, pass the 'object'
        // check, but we can offer a more precise error message here rather than
        // 'of type `object`'.
        var preciseType = getPreciseType(propValue);

        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunctionThatReturnsNull);
  }

  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOf, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }

      var valuesString = JSON.stringify(expectedValues);
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + propValue + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (propValue.hasOwnProperty(key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOfType, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        printWarning$1(
          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
        );
        return emptyFunctionThatReturnsNull;
      }
    }

    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }

      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createStrictShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      // We need to check all keys in case some are required but missing from
      // props.
      var allKeys = objectAssign({}, props[propName], shapeTypes);
      for (var key in allKeys) {
        var checker = shapeTypes[key];
        if (!checker) {
          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
            '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
            '\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')
          );
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }

    return createChainableTypeChecker(validate);
  }

  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }

        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            // Iterator will provide entry [k,v] tuples rather than values.
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }

        return true;
      default:
        return false;
    }
  }

  function isSymbol(propType, propValue) {
    // Native Symbol.
    if (propType === 'symbol') {
      return true;
    }

    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }

    // Fallback for non-spec compliant Symbols which are polyfilled.
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }

    return false;
  }

  // Equivalent of `typeof` but with special handling for array and regexp.
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      // Old webkits (at least until Android 4.0) return 'function' rather than
      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
      // passes PropTypes.object.
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }

  // This handles more types than `getPropType`. Only used for error messages.
  // See `createPrimitiveTypeChecker`.
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }

  // Returns a string that is postfixed to a warning about an invalid type.
  // For example, "undefined" or "of type array"
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }

  // Returns class name of the object, if any.
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }

  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

function emptyFunction() {}

var factoryWithThrowingShims = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret_1) {
      // It is still safe when called from React.
      return;
    }
    var err = new Error(
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
    err.name = 'Invariant Violation';
    throw err;
  }  shim.isRequired = shim;
  function getShim() {
    return shim;
  }  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim,
    exact: getShim
  };

  ReactPropTypes.checkPropTypes = emptyFunction;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var propTypes = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

if (process.env.NODE_ENV !== 'production') {
  var REACT_ELEMENT_TYPE = (typeof Symbol === 'function' &&
    Symbol.for &&
    Symbol.for('react.element')) ||
    0xeac7;

  var isValidElement = function(object) {
    return typeof object === 'object' &&
      object !== null &&
      object.$$typeof === REACT_ELEMENT_TYPE;
  };

  // By explicitly using `prop-types` you are opting into new development behavior.
  // http://fb.me/prop-types-in-prod
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(isValidElement, throwOnDirectAccess);
} else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = factoryWithThrowingShims();
}
});

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var slicedToArray = function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
}();

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

var _templateObject = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2 = taggedTemplateLiteral(['\n      position: absolute;\n      box-sizing: border-box;\n      z-index: 1000;\n      display: flex;\n      width: 100%;\n      height: 100%;\n      min-width: 1px;\n      min-height: 1px;\n      top: 0px;\n      left: 0px;\n      .overlay-pane {\n        ', '\n        position: absolute;\n        pointer-events: auto;\n        display: flex;\n        max-width: 100%;\n        max-height: 100%;\n        box-sizing: border-box;\n        ', '\n        .tooltip {\n          background: ', ';\n          z-index: 10000;\n          border-radius: 5px;\n          .content {\n            padding: 0.5rem 1.25rem;\n            display: flex;\n            align-items: center;\n            font-size: ', ';\n            color: ', ';\n          }\n\n          .arrow {\n            position: absolute;\n            width: 0;\n            height: 0;\n            border-bottom: ', 'px solid ', ';\n            border-left: ', 'px solid transparent;\n            border-right: ', 'px solid transparent;\n          }\n\n          .icon {\n            font-size: 1.25rem;\n          }\n\n          span {\n            line-height: 1.25rem;\n          }\n\n          .icon + span {\n            margin-left: 0.5rem;\n          }\n          ', '\n        }\n      }\n    '], ['\n      position: absolute;\n      box-sizing: border-box;\n      z-index: 1000;\n      display: flex;\n      width: 100%;\n      height: 100%;\n      min-width: 1px;\n      min-height: 1px;\n      top: 0px;\n      left: 0px;\n      .overlay-pane {\n        ', '\n        position: absolute;\n        pointer-events: auto;\n        display: flex;\n        max-width: 100%;\n        max-height: 100%;\n        box-sizing: border-box;\n        ', '\n        .tooltip {\n          background: ', ';\n          z-index: 10000;\n          border-radius: 5px;\n          .content {\n            padding: 0.5rem 1.25rem;\n            display: flex;\n            align-items: center;\n            font-size: ', ';\n            color: ', ';\n          }\n\n          .arrow {\n            position: absolute;\n            width: 0;\n            height: 0;\n            border-bottom: ', 'px solid ', ';\n            border-left: ', 'px solid transparent;\n            border-right: ', 'px solid transparent;\n          }\n\n          .icon {\n            font-size: 1.25rem;\n          }\n\n          span {\n            line-height: 1.25rem;\n          }\n\n          .icon + span {\n            margin-left: 0.5rem;\n          }\n          ', '\n        }\n      }\n    ']),
    _templateObject3 = taggedTemplateLiteral(['\n        .content {\n          flex-direction: row-reverse;\n        }\n        .icon + span {\n          margin-right: 0.5rem;\n        }\n        .arrow {\n          left: ', 'px;\n          top: calc(50% - ', 'px);\n          transform: rotate(270deg);\n        }\n      '], ['\n        .content {\n          flex-direction: row-reverse;\n        }\n        .icon + span {\n          margin-right: 0.5rem;\n        }\n        .arrow {\n          left: ', 'px;\n          top: calc(50% - ', 'px);\n          transform: rotate(270deg);\n        }\n      ']),
    _templateObject4 = taggedTemplateLiteral(['\n        .arrow {\n          right: ', 'px;\n          top: calc(50% - ', 'px);\n          transform: rotate(90deg);\n        }\n      '], ['\n        .arrow {\n          right: ', 'px;\n          top: calc(50% - ', 'px);\n          transform: rotate(90deg);\n        }\n      ']),
    _templateObject5 = taggedTemplateLiteral(['\n        .arrow {\n          bottom: calc(-', 'px + 1px);\n          left: calc(50% - ', 'px);\n          transform: rotate(180deg);\n        }\n      '], ['\n        .arrow {\n          bottom: calc(-', 'px + 1px);\n          left: calc(50% - ', 'px);\n          transform: rotate(180deg);\n        }\n      ']),
    _templateObject6 = taggedTemplateLiteral(['\n        .arrow {\n          top: calc(-', 'px + 2px);\n          left: calc(50% - ', 'px);\n        }\n      '], ['\n        .arrow {\n          top: calc(-', 'px + 2px);\n          left: calc(50% - ', 'px);\n        }\n      ']);

var TooltipStyle = styled__default.div(_templateObject, function (_ref) {
  var theme = _ref.theme,
      status = _ref.status,
      placement = _ref.placement,
      position = _ref.position;

  var arrowSize = 5;
  var color = status ? theme['tooltip' + status + 'Bg'] : theme.tooltipBg;
  var arrowRound = Math.round(-arrowSize - arrowSize / 2 + 1.5);

  return styled.css(_templateObject2, overlayPane(placement), !position && 'visibility: hidden;', color, theme.tooltipFontSize, status ? theme.tooltipStatusFg : theme.tooltipFg, arrowSize, color, arrowSize, arrowSize, placementArrow(placement, arrowSize, arrowRound));
});
var overlayPane = function overlayPane(placement) {
  switch (placement) {
    case 'right':
      return 'transform: translateX(5px);';
    case 'left':
      return 'transform: translateX(-5px);';
    case 'top':
      return 'transform: translateY(-5px);';
    case 'bottom':
      return 'transform: translateY(5px);';
  }
};
var placementArrow = function placementArrow(placement, arrowSize, arrowRound) {
  switch (placement) {
    case 'right':
      return styled.css(_templateObject3, arrowRound, arrowSize / 2.5);
    case 'left':
      return styled.css(_templateObject4, arrowRound, arrowSize / 2.5);
    case 'top':
      return styled.css(_templateObject5, arrowSize, arrowSize);
    case 'bottom':
      return styled.css(_templateObject6, arrowSize, arrowSize);
  }
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var badge = propTypes.shape({
  status: colorState,
  title: propTypes.string,
  position: position
});
var position = propTypes.oneOf(['topRight', 'topLeft', 'bottomRight', 'bottomLeft', 'topStart', 'topEnd', 'bottomStart', 'bottomEnd']);

var colorState = propTypes.oneOf(['Info', 'Success', 'Danger', 'Primary', 'Warning', 'Disabled', 'Active']);

var placement = propTypes.oneOf(['start', 'end', 'right', 'left', 'top', 'bottom']);

var trigger = propTypes.oneOf(['click', 'hover', 'focus', 'hint']);

var statusArray = ['Info', 'Success', 'Danger', 'Primary', 'Warning'];

var size = propTypes.oneOf(['XXS', 'XS', 'SM', 'MD', 'LG', 'XL', 'XXL']);

var shape = propTypes.oneOf(['Rectangle', 'SemiRound', 'Round']);
var customCss = {
  className: propTypes.string,
  style: propTypes.object
};
var itemType = {
  title: propTypes.string.isRequired,
  link: propTypes.any,
  expanded: propTypes.bool,
  group: propTypes.bool,
  hidden: propTypes.bool,
  icon: propTypes.string,
  target: propTypes.string,
  url: propTypes.string
};

var buttonTypes = {
  fullWidth: propTypes.bool,
  hero: propTypes.bool,
  outline: propTypes.bool,
  pulse: propTypes.bool,
  size: propTypes.oneOf(['XS', 'SM', 'MD', 'LG']),
  shape: shape,
  status: propTypes.oneOf([].concat(statusArray, ['Secondary']))
};

var layoutContext = React__default.createContext({
  addClass: function addClass() {},
  removeClass: function removeClass() {},
  addEventListener: function addEventListener() {},
  removeEventListener: function removeEventListener() {},
  dir: 'ltr'
});

function getPhysicalPosition(dir, position) {
  if (position1.includes(position) || position3.includes(position)) {
    return position;
  }
  switch (position) {
    case 'start':
      return dir === 'rtl' ? 'right' : 'left';
    case 'end':
      return dir === 'rtl' ? 'left' : 'right';
    case 'topStart':
      return dir === 'rtl' ? 'topRight' : 'topLeft';
    case 'topEnd':
      return dir === 'rtl' ? 'topLeft' : 'topRight';
    case 'bottomStart':
      return dir === 'rtl' ? 'bottomRight' : 'bottomLeft';
    case 'bottomEnd':
      return dir === 'rtl' ? 'bottomLeft' : 'bottomRight';
  }
  return position;
}

var position1 = ['left', 'right', 'top', 'bottom'];
var position3 = ['topRight', 'topLeft', 'bottomRight', 'bottomLeft'];

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

function usePopoverPosition(props, targetRef, overlayRef) {
  var layout = React.useContext(layoutContext);

  var _useState = React.useState(),
      _useState2 = slicedToArray(_useState, 2),
      position = _useState2[0],
      setPosition = _useState2[1];

  var _useState3 = React.useState(false),
      _useState4 = slicedToArray(_useState3, 2),
      show = _useState4[0],
      setShow = _useState4[1];

  var _useState5 = React.useState(),
      _useState6 = slicedToArray(_useState5, 2),
      placement = _useState6[0],
      setPlacement = _useState6[1];

  React.useEffect(function () {
    if (show) {
      positionHandle();
      window.addEventListener('resize', positionHandle);
      layout.addEventListener('scroll', positionHandle);
      window.addEventListener('click', onClickHandle);
      if (props.eventListener) {
        document.querySelector(props.eventListener).addEventListener('scroll', positionHandle);
      }

      return function () {
        window.removeEventListener('click', onClickHandle);
        window.removeEventListener('resize', positionHandle);
        layout.removeEventListener('scroll', positionHandle);
        if (props.eventListener) {
          document.querySelector(props.eventListener).removeEventListener('scroll', positionHandle);
        }
      };
    }
  }, [show, overlayRef.current]);

  var onClickHandle = function onClickHandle() {
    setShow(false);
  };
  var positionHandle = function positionHandle() {
    var placement = getPhysicalPosition(layout.dir, props.placement);
    var data = getAdjustmentPlacement(placement, targetRef, overlayRef);
    setPosition(data.position);
    setPlacement(data.placement);
  };

  return [position, placement, show, setShow];
}

var getAdjustmentPlacement = function getAdjustmentPlacement(placement, targetRef, overlayRef) {
  var key = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;

  var target = targetRef.current.getBoundingClientRect();
  var overlay = overlayRef.current.getBoundingClientRect();

  if (key > 4) {
    var maxPlacement = getMaxPlacement(target, overlay);
    var _position = getPositionOfPlacement(maxPlacement, target, overlay);
    return { placement: maxPlacement, position: _position };
  }
  var position = getPositionOfPlacement(placement, target, overlay);
  var topBottom = position.top < 0 || position.bottom < 0;
  var leftRight = position.left < 0 || position.right < 0;
  switch (placement) {
    case 'left':
      if (position.left - 15 < 0 || topBottom) {
        return getAdjustmentPlacement('top', targetRef, overlayRef, key + 1);
      }
      break;
    case 'top':
      if (position.top - 15 < 0 || leftRight) {
        return getAdjustmentPlacement('right', targetRef, overlayRef, key + 1);
      }
      break;
    case 'right':
      if (window.innerWidth - position.left - 15 < overlay.width || topBottom) {
        return getAdjustmentPlacement('bottom', targetRef, overlayRef, key + 1);
      }
      break;
    case 'bottom':
      if (window.innerHeight - position.top - 15 < overlay.height || leftRight) {
        return getAdjustmentPlacement('left', targetRef, overlayRef, key + 1);
      }
      break;
  }
  return { placement: placement, position: position };
};

var getMaxPlacement = function getMaxPlacement(target, overlay) {
  var positions = {
    top: target.top - overlay.height,
    bottom: window.innerHeight - target.bottom - overlay.height,
    left: target.left - overlay.width,
    right: window.innerWidth - target.right - overlay.width
  };
  var arr = Object.values(positions);
  var max = Math.max.apply(Math, toConsumableArray(arr));
  for (var key in positions) {
    if (positions.hasOwnProperty(key) && positions[key] === max) {
      return key;
    }
  }
};

var getPositionOfPlacement = function getPositionOfPlacement(placement, target, overlay) {
  var topBottom = {
    top: target.top + target.height / 2 - overlay.height / 2,
    bottom: window.innerHeight - (target.top + target.height / 2 + overlay.height / 2)
  };
  var leftRight = {
    left: target.left + (target.width / 2 - overlay.width / 2),
    right: window.innerWidth - (target.left + target.width / 2 + overlay.width / 2)
  };
  switch (placement) {
    case 'left':
      return _extends({
        left: target.left - overlay.width
      }, topBottom);
    case 'right':
      return _extends({
        left: target.right
      }, topBottom);
    case 'top':
      return _extends({
        top: target.top - overlay.height
      }, leftRight);
    case 'bottom':
      return _extends({
        top: target.bottom
      }, leftRight);
  }
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

function Tooltip(props) {
  var overlayRef = React.useRef();
  var targetRef = React.useRef();

  var _usePopoverPosition = usePopoverPosition(props, targetRef, overlayRef),
      _usePopoverPosition2 = slicedToArray(_usePopoverPosition, 4),
      position$$1 = _usePopoverPosition2[0],
      placement$$1 = _usePopoverPosition2[1],
      show = _usePopoverPosition2[2],
      setShow = _usePopoverPosition2[3];

  var timeOut = void 0;
  var _onMouseLeave = function _onMouseLeave() {
    timeOut = setTimeout(function () {
      setShow(false);
    }, 500);
  };

  var _onMouseEnter = function _onMouseEnter() {
    clearTimeout(timeOut);
  };
  var trigger$$1 = props.trigger;

  return React__default.createElement(
    React.Fragment,
    null,
    show && ReactDOM.createPortal(React__default.createElement(
      TooltipStyle,
      {
        position: position$$1,
        placement: placement$$1,
        status: props.status
      },
      React__default.createElement(
        'div',
        {
          className: 'overlay-pane',
          style: position$$1 && { top: position$$1.top, left: position$$1.left },
          ref: overlayRef,
          onClick: function onClick(e) {
            return e.stopPropagation();
          },
          onMouseEnter: function onMouseEnter() {
            return trigger$$1 === 'hover' && _onMouseEnter();
          },
          onMouseLeave: function onMouseLeave() {
            return trigger$$1 === 'hover' && _onMouseLeave();
          }
        },
        React__default.createElement(
          'div',
          { className: 'tooltip' },
          React__default.createElement('span', { className: 'arrow' }),
          React__default.createElement(
            'div',
            { className: 'content' },
            props.icon && React__default.createElement('i', { className: 'icon ' + props.icon }),
            props.content && React__default.createElement(
              'span',
              null,
              props.content
            )
          )
        )
      )
    ), document.getElementById('overlay-container')),
    React__default.createElement(
      'div',
      {
        style: props.style,
        className: props.className,
        ref: targetRef,
        onFocus: function onFocus() {
          return props.trigger === 'focus' && setShow(true);
        },
        onBlur: function onBlur() {
          return props.trigger === 'focus' && setShow(false);
        },
        onClick: function onClick(e) {
          e.stopPropagation();
          trigger$$1 === 'click' && setShow(!show);
        },
        onMouseEnter: function onMouseEnter() {
          return trigger$$1 === 'hint' ? setShow(true) : trigger$$1 === 'hover' && !show ? setShow(true) : trigger$$1 === 'hover' && _onMouseEnter();
        },
        onMouseLeave: function onMouseLeave() {
          trigger$$1 === 'hint' ? setShow(false) : trigger$$1 === 'hover' && _onMouseLeave();
        }
      },
      props.children
    )
  );
}

Tooltip.propTypes = {
  eventListener: propTypes.string,
  trigger: trigger.isRequired,
  placement: placement.isRequired,
  status: propTypes.oneOf(statusArray),
  icon: propTypes.string,
  content: propTypes.string,
  children: propTypes.node.isRequired,
  style: propTypes.object,
  className: propTypes.string
};

module.exports = Tooltip;
